# coding: utf-8
module Marcman
  MARC = {
    "001"=>
    {:definition=>"Control Number",
     :repeat=>false,
     :indicators=>nil,
     :subfields=>nil,
     :group=>"00X"},
    "003"=>
    {:definition=>"Control Number Identifier",
     :repeat=>false,
     :indicators=>nil,
     :subfields=>nil,
     :group=>"00X"},
    "005"=>
    {:definition=>"Date and Time of Latest Transaction",
     :repeat=>false,
     :indicators=>nil,
     :subfields=>nil,
     :group=>"00X"},
    "006"=>
    {:definition=>
     "Fixed-Length Data Elements-Additional Material Characteristics",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Books", :values=>{}},
      {:definition=>"Music", :values=>{}}],
     :subfields=>nil,
     :group=>"00X"},
    "007"=>
    {:definition=>"Physical Description Fixed Field-General Information",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Map (007/00=a)", :values=>{}},
      {:definition=>"Motion picture (007/00=m)", :values=>{}}],
     :subfields=>nil,
     :group=>"00X"},
    "008"=>
    {:definition=>"Fixed-Length Data Elements-General Information",
     :repeat=>false,
     :indicators=>
     [{:definition=>"All materials", :values=>{}},
      {:definition=>"Music", :values=>{}}],
     :subfields=>nil,
     :group=>"00X"},
    "010"=>
    {:definition=>"Library of Congress Control Number",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"LC control number", :repeat=>false},
       "$b"=>{:definition=>"NUCMC control number"},
       "$z"=>{:definition=>"Canceled/invalid LC control number"}},
     :linkage=>false,
     :group=>"01X-09X"},
    "013"=>
    {:definition=>"Patent Control Information",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Number", :repeat=>false},
       "$b"=>{:definition=>"Country", :repeat=>false},
       "$c"=>{:definition=>"Type of number", :repeat=>false},
       "$d"=>{:definition=>"Date"},
       "$e"=>{:definition=>"Status"},
       "$f"=>{:definition=>"Party to document"}},
     :group=>"01X-09X"},
    "015"=>
    {:definition=>"National Bibliography Number",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"National bibliography number"},
      "$q"=>{:definition=>"Qualifying information"},
      "$z"=>
      {:definition=>"Canceled/invalid national bibliography number",
       :repeat=>true},
      "$2"=>SOURCE},
     :group=>"01X-09X"},
    "016"=>
    {:definition=>"National Bibliographic Agency Control Number",
     :repeat=>true,
     :indicators=>
     [{:definition=>"National bibliographic agency",
       :values=>{"#"=>"Library and Archives Canada",
                 "7"=>"Source specified in subfield $2"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Record control number", :repeat=>false},
       "$z"=>{:definition=>"Canceled/invalid control number"},
       "$2"=>SOURCE},
     :linkage=>false,
     :group=>"01X-09X"},
    "017"=>
    {:definition=>"Copyright or Legal Deposit Number",
     :repeat=>true,
     :indicators=>
     [:undefined,
      {:definition=>"Display constant controller",
       :values=>{"#"=>"Copyright or legal deposit number",
                 "8"=>"No display constant generated"}}],
     :subfields=>{
       "$a"=>{:definition=>"Copyright or legal deposit number"},
       "$b"=>{:definition=>"Assigning agency", :repeat=>false},
       "$d"=>{:definition=>"Date", :repeat=>false},
       "$i"=>{:definition=>"Display text", :repeat=>false},
       "$z"=>{
         :definition=>"Canceled/invalid copyright or legal deposit number",
         :repeat=>true},
       "$2"=>SOURCE},
     :group=>"01X-09X"},
    "018"=>
    {:definition=>"Copyright Article-Fee Code",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Copyright article-fee code", :repeat=>false}},
     :group=>"01X-09X"},
    "020"=>
    {:definition=>"International Standard Book Number",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"International Standard Book Number", :repeat=>false},
       "$c"=>{:definition=>"Terms of availability", :repeat=>false},
       "$q"=>{:definition=>"Qualifying information"},
       "$z"=>{:definition=>"Canceled/invalid ISBN"}},
     :group=>"01X-09X"},
    "022"=>
    {:definition=>"International Standard Serial Number",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Level of international interest",
       :values=>{"#"=>"No level specified",
                 "0"=>"Continuing resource of international interest",
                 "1"=>"Continuing resource not of international interest"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"International Standard Serial Number",
              :repeat=>false},
       "$l"=>{:definition=>"ISSN-L", :repeat=>false},
       "$m"=>{:definition=>"Canceled ISSN-L"},
       "$y"=>{:definition=>"Incorrect ISSN"},
       "$z"=>{:definition=>"Canceled ISSN"},
       "$2"=>SOURCE},
     :group=>"01X-09X"},
    "024"=>
    {:definition=>"Other Standard Identifier",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of standard number or code",
       :values=>
       {"0"=>"International Standard Recording Code",
        "1"=>"Universal Product Code",
        "2"=>"International Standard Music Number",
        "3"=>"International Article Number",
        "4"=>"Serial Item and Contribution Identifier",
        "7"=>"Source specified in subfield $2",
        "8"=>"Unspecified type of standard number or code"}},
      {:definition=>"Difference indicator",
       :values=>
       {"#"=>"No information provided",
        "0"=>"No difference",
        "1"=>"Difference"}}],
     :subfields=>
     {"$a"=>{:definition=>"Standard number or code", :repeat=>false},
      "$c"=>{:definition=>"Terms of availability", :repeat=>false},
      "$d"=>
      {:definition=>"Additional codes following the standard number or code",
       :repeat=>false},
      "$q"=>{:definition=>"Qualifying information"},
      "$z"=>
      {:definition=>"Canceled/invalid standard number or code"},
      "$2"=>{:definition=>"Source of number or code", :repeat=>false}},
     :group=>"01X-09X"},
    "025"=>
    {:definition=>"Overseas Acquisition Number",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Overseas acquisition number"}},
     :linkage=>false,
     :group=>"01X-09X"},
    "026"=>
    {:definition=>"Fingerprint Identifier",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"First and second groups of characters",
              :repeat=>false},
       "$b"=>{:definition=>"Third and fourth groups of characters",
              :repeat=>false},
       "$c"=>{:definition=>"Date", :repeat=>false},
       "$d"=>{:definition=>"Number of volume or part"},
       "$e"=>{:definition=>"Unparsed fingerprint", :repeat=>false},
       "$2"=>SOURCE,
       "$5"=>{:definition=>"Institution to which field applies"}},
     :group=>"01X-09X"},
    "027"=>
    {:definition=>"Standard Technical Report Number",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Standard technical report number", :repeat=>false},
      "$q"=>{:definition=>"Qualifying information"},
      "$z"=>{:definition=>"Canceled/invalid number"}},
     :group=>"01X-09X"},
    "028"=>
    {:definition=>"Publisher or Distributor Number",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of number",
       :values=>
       {"0"=>"Issue number",
        "1"=>"Matrix number",
        "2"=>"Plate number",
        "3"=>"Other music publisher number",
        "4"=>"Video recording publisher number",
        "5"=>"Other publisher number",
        "6"=>"Distributor number"}},
      {:definition=>"Note/added entry controller",
       :values=>
       {"0"=>"No note, no added entry",
        "1"=>"Note, added entry",
        "2"=>"Note, no added entry",
        "3"=>"No note, added entry"}}],
     :subfields=>
     {"$a"=>{:definition=>"Publisher or distributor number", :repeat=>false},
      "$b"=>SOURCE,
      "$q"=>{:definition=>"Qualifying information"}},
     :group=>"01X-09X"},
    "030"=>
    {:definition=>"CODEN Designation",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"CODEN", :repeat=>false},
       "$z"=>{:definition=>"Canceled/invalid CODEN"}},
     :group=>"01X-09X"},
    "031"=>
    {:definition=>"Musical Incipits Information",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Number of work", :repeat=>false},
       "$b"=>{:definition=>"Number of movement", :repeat=>false},
       "$c"=>{:definition=>"Number of excerpt", :repeat=>false},
       "$d"=>{:definition=>"Caption or heading"},
       "$e"=>{:definition=>"Role", :repeat=>false},
       "$g"=>{:definition=>"Clef", :repeat=>false},
       "$m"=>{:definition=>"Voice/instrument", :repeat=>false},
       "$n"=>{:definition=>"Key signature", :repeat=>false},
       "$o"=>{:definition=>"Time signature", :repeat=>false},
       "$p"=>{:definition=>"Musical notation", :repeat=>false},
       "$q"=>{:definition=>"General note"},
       "$r"=>{:definition=>"Key or mode", :repeat=>false},
       "$s"=>{:definition=>"Coded validity note"},
       "$t"=>{:definition=>"Text incipit"},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$y"=>{:definition=>"Link text"},
       "$z"=>PUBNOTE,
       "$2"=>{:definition=>"System code", :repeat=>false}},
     :group=>"01X-09X"},
    "032"=>
    {:definition=>"Postal Registration Number",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Postal registration number", :repeat=>false},
       "$b"=>{:definition=>"Source agency assigning number", :repeat=>false}},
     :group=>"01X-09X"},
    "033"=>
    {:definition=>"Date/Time and Place of an Event",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of date in subfield $a",
       :values=>
       {"#"=>"No date information",
        "0"=>"Single date",
        "1"=>"Multiple single dates",
        "2"=>"Range of dates"}},
      {:definition=>"Type of event",
       :values=>
       {"#"=>"No information provided",
        "0"=>"Capture",
        "1"=>"Broadcast",
        "2"=>"Finding"}}],
     :subfields=>
     {"$a"=>{:definition=>"Formatted date/time"},
      "$b"=>{:definition=>"Geographic classification area code"},
      "$c"=>
      {:definition=>"Geographic classification subarea code"},
      "$p"=>{:definition=>"Place of event"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>{:definition=>"Source of term"},
      "$3"=>MATSPEC},
     :group=>"01X-09X"},
    "034"=>
    {:definition=>"Coded Cartographic Mathematical Data",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of scale",
       :values=>
       {"0"=>"Scale indeterminable/No scale recorded",
        "1"=>"Single scale",
        "3"=>"Range of scales"}},
      {:definition=>"Type of ring",
       :values=>
       {"#"=>"Not applicable", "0"=>"Outer ring", "1"=>"Exclusion ring"}}],
     :subfields=>
     {"$a"=>{:definition=>"Category of scale", :repeat=>false},
      "$b"=>
      {:definition=>"Constant ratio linear horizontal scale"},
      "$c"=>
      {:definition=>"Constant ratio linear vertical scale"},
      "$d"=>
      {:definition=>"Coordinates - westernmost longitude", :repeat=>false},
      "$e"=>
      {:definition=>"Coordinates - easternmost longitude", :repeat=>false},
      "$f"=>
      {:definition=>"Coordinates - northernmost latitude", :repeat=>false},
      "$g"=>
      {:definition=>"Coordinates - southernmost latitude", :repeat=>false},
      "$h"=>{:definition=>"Angular scale"},
      "$j"=>{:definition=>"Declination - northern limit", :repeat=>false},
      "$k"=>{:definition=>"Declination - southern limit", :repeat=>false},
      "$m"=>{:definition=>"Right ascension - eastern limit", :repeat=>false},
      "$n"=>{:definition=>"Right ascension - western limit", :repeat=>false},
      "$p"=>{:definition=>"Equinox", :repeat=>false},
      "$r"=>{:definition=>"Distance from earth", :repeat=>false},
      "$s"=>{:definition=>"G-ring latitude"},
      "$t"=>{:definition=>"G-ring longitude"},
      "$x"=>{:definition=>"Beginning date", :repeat=>false},
      "$y"=>{:definition=>"Ending date", :repeat=>false},
      "$z"=>{:definition=>"Name of extraterrestrial body", :repeat=>false},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :group=>"01X-09X"},
    "035"=>
    {:definition=>"System Control Number",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"System control number", :repeat=>false},
       "$z"=>{:definition=>"Canceled/invalid control number"}},
     :group=>"01X-09X"},
    "036"=>
    {:definition=>"Original Study Number for Computer Data Files",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Original study number", :repeat=>false},
       "$b"=>{:definition=>"Source agency assigning number", :repeat=>false}},
     :group=>"01X-09X"},
    "037"=>
    {:definition=>"Source of Acquisition",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Source of acquisition sequence",
       :values=>
       {"#"=>"Not applicable/No information provided/Earliest",
        "2"=>"Intervening",
        "3"=>"Current/Latest"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Stock number", :repeat=>false},
      "$b"=>{:definition=>"Source of stock number/acquisition", :repeat=>false},
      "$c"=>{:definition=>"Terms of availability"},
      "$f"=>{:definition=>"Form of issue"},
      "$g"=>{:definition=>"Additional format characteristics"},
      "$n"=>NOTER,
      "$3"=>MATSPEC,
      "$5"=>{:definition=>"Institution to which field applies"}},
     :group=>"01X-09X"},
    "038"=>
    {:definition=>"Record Content Licensor",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Record content licensor", :repeat=>false}},
     :group=>"01X-09X"},
    "040"=>
    {:definition=>"Cataloging Source",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Original cataloging agency", :repeat=>false},
       "$b"=>{:definition=>"Language of cataloging", :repeat=>false},
       "$c"=>{:definition=>"Transcribing agency", :repeat=>false},
       "$d"=>{:definition=>"Modifying agency"},
       "$e"=>{:definition=>"Description conventions"}},
     :group=>"01X-09X"},
    "041"=>
    {:definition=>"Language Code",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Translation indication",
       :values=>
       {"#"=>"No information provided",
        "0"=>"Item not a translation/does not include a",
        "1"=>"Item is or includes a translation"}},
      {:definition=>"Source of code",
       :values=>
       {"#"=>"MARC language code", "7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$b"=>
      {:definition=>"Language code of summary or abstract"},
      "$d"=>
      {:definition=>"Language code of sung or spoken text"},
      "$e"=>{:definition=>"Language code of librettos"},
      "$f"=>{:definition=>"Language code of table of contents"},
      "$h"=>{:definition=>"Language code of original"},
      "$j"=>
      {:definition=>"Language code of subtitles or captions"},
      "$k"=>
      {:definition=>"Language code of intermediate translations",
       :repeat=>true},
      "$m"=>
      {:definition=>
       "Language code of original accompanying materials other than librettos",
       :repeat=>true},
      "$n"=>{:definition=>"Language code of original libretto"},
      "$2"=>{:definition=>"Source of code", :repeat=>false}},
     :group=>"01X-09X"},
    "042"=>
    {:definition=>"Authentication Code",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{"$a"=>{:definition=>"Authentication code"}},
     :linkage=>false,
     :fieldlink=>false,
     :group=>"01X-09X"},
    "043"=>
    {:definition=>"Geographic Area Code",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Geographic area code"},
      "$b"=>{:definition=>"Local GAC code"},
      "$c"=>{:definition=>"ISO code"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>{:definition=>"Source of local code"}},
     :group=>"01X-09X"},
    "044"=>
    {:definition=>"Country of Publishing/Producing Entity Code",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"MARC country code"},
       "$b"=>{:definition=>"Local subentity code"},
       "$c"=>{:definition=>"ISO country code"},
       "$2"=>{:definition=>"Source of local subentity code"}},
     :group=>"01X-09X"},
    "045"=>
    {:definition=>"Time Period of Content",
     :repeat=>false,
     :indicators=>
     [{:definition=>"Type of time period in subfield $b or $c",
       :values=>{"0"=>"Single date/time",
                 "1"=>"Multiple single dates/times",
                 "2"=>"Range of dates/times"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Time period code"},
       "$b"=>{:definition=>"Formatted 9999 B.C. through C.E. time period",
              :repeat=>true},
       "$c"=>{:definition=>"Formatted pre-9999 B.C. time period"}},
     :group=>"01X-09X"},
    "046"=>
    {:definition=>"Special Coded Dates",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Type of date code", :repeat=>false},
      "$b"=>{:definition=>"Date 1, B.C.E. date", :repeat=>false},
      "$c"=>{:definition=>"Date 1, C.E. date", :repeat=>false},
      "$d"=>{:definition=>"Date 2, B.C.E. date", :repeat=>false},
      "$e"=>{:definition=>"Date 2, C.E. date", :repeat=>false},
      "$j"=>{:definition=>"Date resource modified", :repeat=>false},
      "$k"=>{:definition=>"Beginning or single date created", :repeat=>false},
      "$l"=>{:definition=>"Ending date created", :repeat=>false},
      "$m"=>{:definition=>"Beginning of date valid", :repeat=>false},
      "$n"=>{:definition=>"End of date valid", :repeat=>false},
      "$o"=>
      {:definition=>"Single or starting date for aggregated content",
       :repeat=>false},
      "$p"=>{:definition=>"Ending date for aggregated content", :repeat=>false},
      "$2"=>{:definition=>"Source of date", :repeat=>false}},
     :linkage=>true,
     :group=>"01X-09X"},
    "047"=>
    {:definition=>"Form of Musical Composition Code",
     :repeat=>true,
     :indicators=>[:undefined,
                   {:definition=>"Source of code",
                    :values=>{"#"=>"MARC musical composition code",
                              "7"=>"Source specified in subfield $2"}}],
     :subfields=>{
       "$a"=>{:definition=>"Form of musical composition code"},
       "$2"=>{:definition=>"Source of code", :repeat=>false}},
     :linkage=>false,
     :group=>"01X-09X"},
    "048"=>
    {:definition=>"Number of Musical Instruments or Voices Code",
     :repeat=>true,
     :indicators=>[:undefined, {
                     :definition=>"Source of code",
                     :values=>{"#"=>"MARC code",
                               "7"=>"Source specified in subfield $2"}}],
     :subfields=>{
       "$a"=>{:definition=>"Performer or ensemble"},
       "$b"=>{:definition=>"Soloist"},
       "$2"=>{:definition=>"Source of code", :repeat=>false}},
     :linkage=>false,
     :group=>"01X-09X"},
    "050"=>
    {:definition=>"Library of Congress Call Number",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Existence in LC collection",
       :values=>
       {"#"=>"No information provided",
        "0"=>"Item is in LC",
        "1"=>"Item is not in LC"}},
      {:definition=>"Source of call number",
       :values=>
       {"0"=>"Assigned by LC", "4"=>"Assigned by agency other than LC"}}],
     :subfields=>
     {"$a"=>{:definition=>"Classification number"},
      "$b"=>ITEMNUM,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"01X-09X"},
    "051"=>
    {:definition=>"Library of Congress Copy, Issue, Offprint Statement",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Classification number", :repeat=>false},
       "$b"=>ITEMNUM,
       "$c"=>{:definition=>"Copy information", :repeat=>false}},
     :linkage=>false,
     :group=>"01X-09X"},
    "052"=>
    {:definition=>"Geographic Classification",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Code source",
       :values=>
       {"#"=>"Library of Congress Classification",
        "1"=>"U.S. Dept. of Defense Classification",
        "7"=>"Source specified in subfield $2"}},
      :undefined],
     :subfields=>
     {"$a"=>
      {:definition=>"Geographic classification area code", :repeat=>false},
      "$b"=>
      {:definition=>"Geographic classification subarea code"},
      "$d"=>{:definition=>"Populated place name"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>{:definition=>"Code source", :repeat=>false}},
     :linkage=>true,
     :group=>"01X-09X"},
    "055"=>
    {:definition=>"Classification Numbers Assigned in Canada",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Existence in LAC collection",
       :values=>
       {"#"=>"Information not provided",
        "0"=>"Work held by LAC",
        "1"=>"Work not held by LAC"}},
      {:definition=>"Type, completeness, source of class/call number",
       :values=>
       {"0"=>"LC-based call number assigned by LAC",
        "1"=>"Complete LC class number assigned by LAC",
        "2"=>"Incomplete LC class number assigned by LAC",
        "3"=>"LC-based call number assigned by the contributing library",
        "4"=>"Complete LC class number assigned by the contributing library",
        "5"=>"Incomplete LC class number assigned by the contributing library",
        "6"=>"Other call number assigned by LAC",
        "7"=>"Other class number assigned by LAC",
        "8"=>"Other call number assigned by the contributing library",
        "9"=>"Other class number assigned by the contributing library"}}],
     :subfields=>
     {"$a"=>{:definition=>"Classification number", :repeat=>false},
      "$b"=>ITEMNUM,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>{:definition=>"Source of call/class number", :repeat=>false}},
     :linkage=>true,
     :group=>"01X-09X"},
    "060"=>
    {:definition=>"National Library of Medicine Call Number",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Existence in NLM collection",
       :values=>
       {"#"=>"No information provided",
        "0"=>"Item is in NLM",
        "1"=>"Item is not in NLM"}},
      {:definition=>"Source of call number",
       :values=>
       {"0"=>"Assigned by NLM", "4"=>"Assigned by agency other than NLM"}}],
     :subfields=>
     {"$a"=>{:definition=>"Classification number"},
      "$b"=>ITEMNUM,
      "$0"=>ARECNUM,
      "$1"=>RWURI},
     :linkage=>false,
     :group=>"01X-09X"},
    "061"=>
    {:definition=>"National Library of Medicine Copy Statement",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Classification number"},
       "$b"=>ITEMNUM,
       "$c"=>{:definition=>"Copy information", :repeat=>false}},
     :linkage => false,
     :group=>"01X-09X"},
    "066"=>
    {:definition=>"Character Sets Present",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Primary G0 character set", :repeat=>false},
       "$b"=>{:definition=>"Primary G1 character set", :repeat=>false},
       "$c"=>{:definition=>"Alternate G0 or G1 character set"}},
     :linkage=>false,
     :fieldlink=>false,
     :group=>"01X-09X"},
    "070"=>
    {:definition=>"National Agricultural Library Call Number",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Existence in NAL collection",
       :values=>
       {"#"=>"No information provided",
        "0"=>"Item is in NAL",
        "1"=>"Item is not in NAL"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Classification number"},
      "$b"=>ITEMNUM,
      "$0"=>ARECNUM,
      "$1"=>RWURI},
     :linkage=>false,
     :group=>"01X-09X"},
    "071"=>
    {:definition=>"National Agricultural Library Copy Statement",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Classification number"},
       "$b"=>ITEMNUM,
       "$c"=>{:definition=>"Copy information"}},
     :linkage=>false,
     :group=>"01X-09X"},
    "072"=>
    {:definition=>"Subject Category Code",
     :repeat=>true,
     :indicators=>[:undefined,
                   {:definition=>"Code source",
                    :values=>{"0"=>"NAL subject category code list",
                              "7"=>"Source specified in subfield $2"}}],
     :subfields=>{
       "$a"=>{:definition=>"Subject category code", :repeat=>false},
       "$x"=>{:definition=>"Subject category code subdivision"},
       "$2"=>SOURCE},
     :group=>"01X-09X"},
    "074"=>
    {:definition=>"GPO Item Number",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"GPO item number", :repeat=>false},
       "$z"=>{:definition=>"Canceled/invalid GPO item number"}},
     :linkage=>false,
     :group=>"01X-09X"},
    "080"=>
    {:definition=>"Universal Decimal Classification Number",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of edition",
       :values=>{"#"=>"No information provided", "0"=>"Full", "1"=>"Abridged"}},
      :undefined],
     :subfields=>
     {"$a"=>
      {:definition=>"Universal Decimal Classification number", :repeat=>false},
      "$b"=>ITEMNUM,
      "$x"=>{:definition=>"Common auxiliary subdivision"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>{:definition=>"Edition identifier", :repeat=>false}},
     :linkage=>true,
     :group=>"01X-09X"},
    "082"=>
    {:definition=>"Dewey Decimal Classification Number",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of edition",
       :values=>{"0"=>"Full edition", "1"=>"Abridged edition"}},
      {:definition=>"Source of classification number",
       :values=>
       {"#"=>"No information provided",
        "0"=>"Assigned by LC",
        "4"=>"Assigned by agency other than LC"}}],
     :subfields=>
     {"$a"=>{:definition=>"Classification number"},
      "$b"=>ITEMNUM,
      "$m"=>{:definition=>"Standard or optional designation", :repeat=>false},
      "$q"=>{:definition=>"Assigning agency", :repeat=>false},
      "$2"=>{:definition=>"Edition number", :repeat=>false}},
     :linkage=>true,
     :group=>"01X-09X"},
    "083"=>
    {:definition=>"Additional Dewey Decimal Classification Number",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of edition",
       :values=>{"0"=>"Full edition", "1"=>"Abridged edition"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Classification number"},
      "$c"=>
      {:definition=>"Classification number--Ending number of span",
       :repeat=>true},
      "$m"=>{:definition=>"Standard or optional designation", :repeat=>false},
      "$q"=>{:definition=>"Assigning agency", :repeat=>false},
      "$y"=>{
        :definition=>"Table sequence number for internal subarrangement or add table",
        :repeat=>true},
      "$z"=>{:definition=>"Table identification"},
      "$2"=>{:definition=>"Edition number", :repeat=>false}},
     :linkage=>true,
     :group=>"01X-09X"},
    "084"=>
    {:definition=>"Other Classification Number",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Classification number"},
      "$b"=>ITEMNUM,
      "$q"=>{:definition=>"Assigning agency", :repeat=>false},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>{:definition=>"Number source", :repeat=>false}},
     :linkage=>true,
     :group=>"01X-09X"},
    "085"=>
    {:definition=>"Synthesized Classification Number Components",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{
         :definition=>"Number where instructions are found-single number or beginning number of span",
         :repeat=>true},
       "$b"=>{:definition=>"Base number"},
       "$c"=>
       {:definition=>"Classification number-ending number of span",
        :repeat=>true},
       "$f"=>{:definition=>"Facet designator"},
       "$r"=>{:definition=>"Root number"},
       "$s"=>{
         :definition=>"Digits added from classification number in schedule or external table",
         :repeat=>true},
       "$t"=>{
         :definition=>"Digits added from internal subarrangement or add table",
         :repeat=>true},
       "$u"=>{:definition=>"Number being analyzed"},
       "$v"=>{
         :definition=>"Number in internal subarrangement or add table where instructions are found",
         :repeat=>true},
       "$w"=>{
         :definition=>"Table identification-Internal subarrangement or add table",
         :repeat=>true},
       "$y"=>{
         :definition=>"Table sequence number for internal subarrangement or add table",
         :repeat=>true},
       "$z"=>{:definition=>"Table identification"},
       "$0"=>ARECNUM,
       "$1"=>RWURI},
     :linkage=>true,
     :group=>"01X-09X"},
    "086"=>
    {:definition=>"Government Document Classification Number",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Number source",
       :values=>
       {"#"=>"Source specified in subfield $2",
        "0"=>"Superintendent of Documents Classification System",
        "1"=>"Government of Canada Publications: Outline of Classification"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Classification number", :repeat=>false},
      "$z"=>
      {:definition=>"Canceled/invalid classification number"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>{:definition=>"Number source", :repeat=>false}},
     :linkage=>true,
     :group=>"01X-09X"},
    "088"=>
    {:definition=>"Report Number",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Report number", :repeat=>false},
      "$z"=>{:definition=>"Canceled/invalid report number"}},
     :linkage=>true,
     :group=>"01X-09X"},
    "09X"=>
    {:definition=>"Local Call Numbers",
     :repeat=>false,
     :indicators=>nil,
     :subfields=>nil,
     :group=>"01X-09X"},
    "100"=>
    {:definition=>"Main Entry-Personal Name",
     :repeat=>false,
     :indicators=>
     [{:definition=>"Type of personal name entry element",
       :values=>{"0"=>"Forename", "1"=>"Surname", "3"=>"Family name"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Personal name", :repeat=>false},
      "$b"=>{:definition=>"Numeration", :repeat=>false},
      "$c"=>
      {:definition=>"Titles and words associated with a name"},
      "$d"=>{:definition=>"Dates associated with a name", :repeat=>false},
      "$e"=>RELATOR,
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$j"=>{:definition=>"Attribution qualifier"},
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$n"=>NUMPART,
      "$p"=>NAMEPRT,
      "$q"=>{:definition=>"Fuller form of name", :repeat=>false},
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"1XX"},
    "110"=>
    {:definition=>"Main Entry-Corporate Name",
     :repeat=>false,
     :indicators=>
     [{:definition=>"Type of corporate name entry element",
       :values=>
       {"0"=>"Inverted name",
        "1"=>"Jurisdiction name",
        "2"=>"Name in direct order"}},
      :undefined],
     :subfields=>
     {"$a"=>
      {:definition=>"Corporate name or jurisdiction name as entry element",
       :repeat=>false},
      "$b"=>{:definition=>"Subordinate unit"},
      "$c"=>{:definition=>"Location of meeting"},
      "$d"=>{:definition=>"Date of meeting or treaty signing"},
      "$e"=>RELATOR,
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$n"=>{:definition=>"Number of part/section/meeting"},
      "$p"=>NAMEPRT,
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"1XX"},
    "111"=>
    {:definition=>"Main Entry-Meeting Name",
     :repeat=>false,
     :indicators=>
     [{:definition=>"Type of meeting name entry element",
       :values=>
       {"0"=>"Inverted name",
        "1"=>"Jurisdiction name",
        "2"=>"Name in direct order"}},
      :undefined],
     :subfields=>
     {"$a"=>
      {:definition=>"Meeting name or jurisdiction name as entry element",
       :repeat=>false},
      "$c"=>{:definition=>"Location of meeting"},
      "$d"=>{:definition=>"Date of meeting or treaty signing"},
      "$e"=>{:definition=>"Subordinate unit"},
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$j"=>RELATOR,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$n"=>{:definition=>"Number of part/section/meeting"},
      "$p"=>NAMEPRT,
      "$q"=>
      {:definition=>
       "Name of meeting following jurisdiction name entry element",
       :repeat=>false},
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"1XX"},
    "130"=>
    {:definition=>"Main Entry-Uniform Title",
     :repeat=>false,
     :indicators=>
     [{:definition=>"Nonfiling characters",
       :values=>{"0-9"=>"Number of nonfiling characters"}},
      :undefined],
     :subfields=>
     {"$a"=>UNIFORM,
      "$d"=>{:definition=>"Date of treaty signing"},
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>NUMPART,
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$r"=>MUSKEY,
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$0"=>ARECNUM,
      "$1"=>RWURI},
     :linkage=>true,
     :group=>"1XX"},
    "210"=>
    {:definition=>"Abbreviated Title",
     :repeat=>true,
     :indicators=>[
       {:definition=>"Title added entry", :values=>{"0"=>"No added entry",
                                                    "1"=>"Added entry"}},
       {:definition=>"Type", :values=>{"#"=>"Abbreviated key title",
                                       "0"=>"Other abbreviated title"}}],
     :subfields=>{
       "$a"=>{:definition=>"Abbreviated title", :repeat=>false},
       "$b"=>QUALINF,
       "$2"=>{:definition=>"Source"}},
     :group=>"20X-24X"},
    "222"=>
    {:definition=>"Key Title",
     :repeat=>true,
     :indicators=>
     [:undefined, {:definition=>"Nonfiling characters",
                   :values=>{"0"=>"No nonfiling characters",
                             "1-9"=>"Number of nonfiling characters"}}],
     :subfields=>{
       "$a"=>{:definition=>"Key title", :repeat=>false},
       "$b"=>QUALINF},
     :group=>"20X-24X"},
    "240"=>
    {:definition=>"Uniform Title",
     :repeat=>false,
     :indicators=>
     [{:definition=>"Uniform title printed or displayed",
       :values=>{"0"=>"Not printed or displayed", "1"=>"Printed or displayed"}},
      {:definition=>"Nonfiling characters",
       :values=>{"0-9"=>"Number of nonfiling characters"}}],
     :subfields=>
     {"$a"=>UNIFORM,
      "$d"=>{:definition=>"Date of treaty signing"},
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>NUMPART,
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$r"=>MUSKEY,
      "$s"=>VRSNR,
      "$0"=>ARECNUM,
      "$1"=>RWURI},
     :linkage=>true,
     :group=>"20X-24X"},
    "242"=>
    {:definition=>"Translation of Title by Cataloging Agency",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Title added entry", :values=>{"0"=>"No added entry",
                                                   "1"=>"Added entry"}},
      {:definition=>"Nonfiling characters",
       :values=>{"0"=>"No nonfiling characters",
                 "1-9"=>"Number of nonfiling characters"}}],
     :subfields=>{
       "$a"=>TITLENR,
       "$b"=>{:definition=>"Remainder of title", :repeat=>false},
       "$c"=>{:definition=>"Statement of responsibility, etc.",
              :repeat=>false},
       "$h"=>MEDIUM,
       "$n"=>{:definition=>"Number of part/section of a work",
              :repeat=>true}, 	
       "$p"=>NAMEPRT,
       "$y"=>{:definition=>"Language code of translated title",
              :repeat=>false}},
     :group=>"20X-24X"},
    "243"=>
    {:definition=>"Collective Uniform Title",
     :repeat=>false,
     :indicators=>
     [{:definition=>"Uniform title printed or displayed",
       :values=>{"0"=>"Not printed or displayed", "1"=>"Printed or displayed"}},
      {:definition=>"Nonfiling characters",
       :values=>{"1-9"=>"Number of nonfiling characters"}}],
     :subfields=>
     {"$a"=>UNIFORM,
      "$d"=>{:definition=>"Date of treaty signing"},
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>NUMPART,
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$r"=>MUSKEY,
      "$s"=>VRSNR},
     :linkage=>true,
     :group=>"20X-24X"},
    "245"=>
    {:definition=>"Title Statement",
     :repeat=>false,
     :indicators=>
     [{:definition=>"Title added entry", :values=>{"0"=>"No added entry",
                                                   "1"=>"Added entry"}},
      {:definition=>"Nonfiling characters",
       :values=>{"0"=>"No nonfiling characters",
                 "1-9"=>"Number of nonfiling characters"}}],
     :subfields=>{
       "$a"=>TITLENR,
       "$b"=>{:definition=>"Remainder of title", :repeat=>false},
       "$c"=>{:definition=>"Statement of responsibility, etc.", :repeat=>false},
       "$f"=>{:definition=>"Inclusive dates", :repeat=>false},
       "$g"=>{:definition=>"Bulk dates", :repeat=>false},
       "$h"=>MEDIUM,
       "$k"=>{:definition=>"Form"},
       "$n"=>NUMPART,
       "$p"=>NAMEPRT,
       "$s"=>{:definition=>"Version", :repeat=>false}},
     :group=>"20X-24X"},
    "246"=>
    {:definition=>"Varying Form of Title",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note/added entry controller",
       :values=>
       {"0"=>"Note, no added entry",
        "1"=>"Note, added entry",
        "2"=>"No note, no added entry",
        "3"=>"No note, added entry"}},
      {:definition=>"Type of title",
       :values=>
       {"#"=>"No type specified",
        "0"=>"Portion of title",
        "1"=>"Parallel title",
        "2"=>"Distinctive title",
        "3"=>"Other title",
        "4"=>"Cover title",
        "5"=>"Added title page title",
        "6"=>"Caption title",
        "7"=>"Running title",
        "8"=>"Spine title"}}],
     :subfields=>
     {"$a"=>{:definition=>"Title proper/short title", :repeat=>false},
      "$b"=>{:definition=>"Remainder of title", :repeat=>false},
      "$f"=>{:definition=>"Date or sequential designation", :repeat=>false},
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$i"=>{:definition=>"Display text", :repeat=>false},
      "$n"=>NUMPART,
      "$p"=>NAMEPRT,
      "$5"=>INSTAPP},
     :linkage=>true,
     :group=>"20X-24X"},
    "247"=>
    {:definition=>"Former Title",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Title added entry",
       :values=>{"0"=>"No added entry", "1"=>"Added entry"}},
      {:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}}],
     :subfields=>
     {"$a"=>TITLENR,
      "$b"=>{:definition=>"Remainder of title", :repeat=>false},
      "$f"=>{:definition=>"Date or sequential designation", :repeat=>false},
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$n"=>NUMPART,
      "$p"=>NAMEPRT,
      "$x"=>ISSNNR},
     :linkage=>true,
     :group=>"20X-24X"},
    "250"=>
    {:definition=>"Edition Statement",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Edition statement", :repeat=>false},
      "$b"=>{:definition=>"Remainder of edition statement", :repeat=>false},
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"25X-28X"},
    "254"=>
    {:definition=>"Musical Presentation Statement",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{"$a"=>{:definition=>"Musical presentation statement",
                         :repeat=>false}},
     :group=>"25X-28X"},
    "255"=>
    {:definition=>"Cartographic Mathematical Data",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Statement of scale", :repeat=>false},
       "$b"=>{:definition=>"Statement of projection", :repeat=>false},
       "$c"=>{:definition=>"Statement of coordinates", :repeat=>false},
       "$d"=>{:definition=>"Statement of zone", :repeat=>false},
       "$e"=>{:definition=>"Statement of equinox", :repeat=>false},
       "$f"=>{:definition=>"Outer G-ring coordinate pairs", :repeat=>false},
       "$g"=>{:definition=>"Exclusion G-ring coordinate pairs", :repeat=>false}},
     :group=>"25X-28X"},
    "256"=>
    {:definition=>"Computer File Characteristics",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{"$a"=>{:definition=>"Computer file characteristics",
                         :repeat=>false}},
     :group=>"25X-28X"},
    "257"=>
    {:definition=>"Country of Producing Entity",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Country of producing entity"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE},
     :linkage=>true,
     :group=>"25X-28X"},
    "258"=>
    {:definition=>"Philatelic Issue Data",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Issuing jurisdiction", :repeat=>false},
       "$b"=>{:definition=>"Denomination", :repeat=>false}},
     :group=>"25X-28X"},
    "260"=>
    {:definition=>"Publication, Distribution, etc. (Imprint)",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Sequence of publishing statements",
       :values=>
       {"#"=>
        "Not applicable/No information provided/Earliest available publisher",
        "2"=>"Intervening publisher",
        "3"=>"Current/latest publisher"}},
      :undefined],
     :subfields=>
     {"$a"=>
      {:definition=>"Place of publication, distribution, etc."},
      "$b"=>
      {:definition=>"Name of publisher, distributor, etc."},
      "$c"=>
      {:definition=>"Date of publication, distribution, etc."},
      "$e"=>{:definition=>"Place of manufacture"},
      "$f"=>{:definition=>"Manufacturer"},
      "$g"=>{:definition=>"Date of manufacture"},
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"25X-28X"},
    "263"=>
    {:definition=>"Projected Publication Date",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{"$a"=>{:definition=>"Projected publication date",
                         :repeat=>false}},
     :group=>"25X-28X"},
    "264"=>
    {:definition=>
     "Production, Publication, Distribution, Manufacture, and Copyright Notice",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Sequence of statements",
       :values=>
       {"#"=>"Not applicable/No information provided/Earliest",
        "2"=>"Intervening",
        "3"=>"Current/Latest"}},
      {:definition=>"Function of entity",
       :values=>
       {"0"=>"Production",
        "1"=>"Publication",
        "2"=>"Distribution",
        "3"=>"Manufacture",
        "4"=>"Copyright notice date"}}],
     :subfields=>
     {"$a"=>
      {:definition=>
       "Place of production, publication, distribution, manufacture",
       :repeat=>true},
      "$b"=>
      {:definition=>"Name of producer, publisher, distributor, manufacturer",
       :repeat=>true},
      "$c"=>
      {:definition=>
       "Date of production, publication, distribution, manufacture, or copyright notice",
       :repeat=>true},
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"25X-28X"},
    "270"=>
    {:definition=>"Address",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Level",
       :values=>{"#"=>"No level specified", "1"=>"Primary", "2"=>"Secondary"}},
      {:definition=>"Type of address",
       :values=>
       {"#"=>"No type specified",
        "0"=>"Mailing",
        "7"=>"Type specified in subfield $i"}}],
     :subfields=>
     {"$a"=>{:definition=>"Address"},
      "$b"=>{:definition=>"City", :repeat=>false},
      "$c"=>{:definition=>"State or province", :repeat=>false},
      "$d"=>{:definition=>"Country", :repeat=>false},
      "$e"=>{:definition=>"Postal code", :repeat=>false},
      "$f"=>{:definition=>"Terms preceding attention name", :repeat=>false},
      "$g"=>{:definition=>"Attention name", :repeat=>false},
      "$h"=>{:definition=>"Attention position", :repeat=>false},
      "$i"=>{:definition=>"Type of address", :repeat=>false},
      "$j"=>{:definition=>"Specialized telephone number"},
      "$k"=>{:definition=>"Telephone number"},
      "$l"=>{:definition=>"Fax number"},
      "$m"=>{:definition=>"Electronic mail address"},
      "$n"=>{:definition=>"TDD or TTY number"},
      "$p"=>{:definition=>"Contact person"},
      "$q"=>{:definition=>"Title of contact person"},
      "$r"=>{:definition=>"Hours"},
      "$z"=>PUBNOTE,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"25X-28X"},
    "300"=>
    {:definition=>"Physical Description",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Extent"},
      "$b"=>{:definition=>"Other physical details", :repeat=>false},
      "$c"=>{:definition=>"Dimensions"},
      "$e"=>{:definition=>"Accompanying material", :repeat=>false},
      "$f"=>{:definition=>"Type of unit"},
      "$g"=>{:definition=>"Size of unit"},
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "306"=>
    {:definition=>"Playing Time",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{"$a"=>{:definition=>"Playing time"}},
     :group=>"3XX"},
    "307"=>
    {:definition=>"Hours, Etc.",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"Hours",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Hours", :repeat=>false},
       "$b"=>{:definition=>"Additional information", :repeat=>false}},
     :group=>"3XX"},
    "310"=>
    {:definition=>"Current Publication Frequency",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Current publication frequency", :repeat=>false},
       "$b"=>{:definition=>"Date of current publication frequency",
              :repeat=>false}},
     :group=>"3XX"},
    "321"=>
    {:definition=>"Former Publication Frequency",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Former publication frequency", :repeat=>false},
       "$b"=>{:definition=>"Dates of former publication frequency",
              :repeat=>false}},
     :group=>"3XX"},
    "336"=>
    {:definition=>"Content Type",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Content type term"},
      "$b"=>{:definition=>"Content type code"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "337"=>
    {:definition=>"Media Type",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Media type term"},
      "$b"=>{:definition=>"Media type code"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "338"=>
    {:definition=>"Carrier Type",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Carrier type term"},
      "$b"=>{:definition=>"Carrier type code"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "340"=>
    {:definition=>"Physical Medium",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Material base and configuration"},
      "$b"=>{:definition=>"Dimensions"},
      "$c"=>{:definition=>"Materials applied to surface"},
      "$d"=>{:definition=>"Information recording technique"},
      "$e"=>{:definition=>"Support"},
      "$f"=>{:definition=>"Production rate/ratio"},
      "$g"=>{:definition=>"Color content"},
      "$h"=>{:definition=>"Location within medium"},
      "$i"=>{:definition=>"Technical specifications of medium"},
      "$j"=>{:definition=>"Generation"},
      "$k"=>{:definition=>"Layout"},
      "$m"=>{:definition=>"Book format"},
      "$n"=>{:definition=>"Font size"},
      "$o"=>{:definition=>"Polarity"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "342"=>
    {:definition=>"Geospatial Reference Data",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Geospatial reference dimension",
       :values=>{"0"=>"Horizontal coordinate system",
                 "1"=>"Vertical coordinate system"}},
      {:definition=>"Geospatial reference method",
       :values=>{"0"=>"Geographic",
                 "1"=>"Map projection",
                 "2"=>"Grid coordinate system",
                 "3"=>"Local planar",
                 "4"=>"Local",
                 "5"=>"Geodetic model",
                 "6"=>"Altitude",
                 "7"=>"Method specified in $2",
                 "8"=>"Depth"}}],
     :subfields=>{
       "$a"=>{:definition=>"Name", :repeat=>false},
       "$b"=>{:definition=>"Coordinate units or distance units", :repeat=>false},
       "$c"=>{:definition=>"Latitude resolution", :repeat=>false},
       "$d"=>{:definition=>"Longitude resolution", :repeat=>false},
       "$e"=>{:definition=>"Standard parallel or oblique line latitude",
              :repeat=>true},
       "$f"=>{:definition=>"Oblique line longitude"},
       "$g"=>{:definition=>"Longitude of central meridian or projection center",
              :repeat=>false},
       "$h"=>{:definition=>"Latitude of projection center or projection origin",
              :repeat=>false},
       "$i"=>{:definition=>"False easting", :repeat=>false},
       "$j"=>{:definition=>"False northing", :repeat=>false},
       "$k"=>{:definition=>"Scale factor", :repeat=>false},
       "$l"=>{:definition=>"Height of perspective point above surface",
              :repeat=>false},
       "$m"=>{:definition=>"Azimuthal angle", :repeat=>false},
       "$n"=>{
         :definition=>"Azimuth measure point longitude or straight vertical longitude from pole",
         :repeat=>false},
       "$o"=>{:definition=>"Landsat number and path number", :repeat=>false},
       "$p"=>{:definition=>"Zone identifier", :repeat=>false},
       "$q"=>{:definition=>"Ellipsoid name", :repeat=>false},
       "$r"=>{:definition=>"Semi-major axis", :repeat=>false},
       "$s"=>{:definition=>"Denominator of flattening ratio", :repeat=>false},
       "$t"=>{:definition=>"Vertical resolution", :repeat=>false},
       "$u"=>{:definition=>"Vertical encoding method", :repeat=>false},
       "$v"=>{
         :definition=>"Local planar, local, or other projection or grid description",
         :repeat=>false},
       "$w"=>{:definition=>"Local planar or local georeference information",
              :repeat=>false},
       "$2"=>{:definition=>"Reference method used", :repeat=>false}},
     :group=>"3XX"},
    "343"=>
    {:definition=>"Planar Coordinate Data",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Planar coordinate encoding method", :repeat=>false},
       "$b"=>{:definition=>"Planar distance units", :repeat=>false},
       "$c"=>{:definition=>"Abscissa resolution", :repeat=>false},
       "$d"=>{:definition=>"Ordinate resolution", :repeat=>false},
       "$e"=>{:definition=>"Distance resolution", :repeat=>false},
       "$f"=>{:definition=>"Bearing resolution", :repeat=>false},
       "$g"=>{:definition=>"Bearing units", :repeat=>false},
       "$h"=>{:definition=>"Bearing reference direction", :repeat=>false},
       "$i"=>{:definition=>"Bearing reference meridian", :repeat=>false}},
     :group=>"3XX"},
    "344"=>
    {:definition=>"Sound Characteristics",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Type of recording"},
      "$b"=>{:definition=>"Recording medium"},
      "$c"=>{:definition=>"Playing speed"},
      "$d"=>{:definition=>"Groove characteristic"},
      "$e"=>{:definition=>"Track configuration"},
      "$f"=>{:definition=>"Tape configuration"},
      "$g"=>{:definition=>"Configuration of playback channels"},
      "$h"=>{:definition=>"Special playback characteristics"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "345"=>
    {:definition=>"Projection Characteristics of Moving Image",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Presentation format"},
      "$b"=>{:definition=>"Projection speed"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "346"=>
    {:definition=>"Video Characteristics",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Video format"},
      "$b"=>{:definition=>"Broadcast standard"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "347"=>
    {:definition=>"Digital File Characteristics",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"File type"},
      "$b"=>{:definition=>"Encoding format"},
      "$c"=>{:definition=>"File size"},
      "$d"=>{:definition=>"Resolution"},
      "$e"=>{:definition=>"Regional encoding"},
      "$f"=>{:definition=>"Encoded bitrate"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "348"=>
    {:definition=>"Format of Notated Music",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Format of notated music term"},
      "$b"=>{:definition=>"Format of notated music code"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SRCTERM,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "351"=>
    {:definition=>"Organization and Arrangement of Materials",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Organization"},
       "$b"=>{:definition=>"Arrangement"},
       "$c"=>{:definition=>"Hierarchical level", :repeat=>false},
       "$3"=>MATSPEC},
     :group=>"3XX"},
    "352"=>
    {:definition=>"Digital Graphic Representation",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Direct reference method", :repeat=>false},
       "$b"=>{:definition=>"Object type"},
       "$c"=>{:definition=>"Object count"},
       "$d"=>{:definition=>"Row count", :repeat=>false},
       "$e"=>{:definition=>"Column count", :repeat=>false},
       "$f"=>{:definition=>"Vertical count", :repeat=>false},
       "$g"=>{:definition=>"VPF topology level", :repeat=>false},
       "$i"=>{:definition=>"Indirect reference description", :repeat=>false},
       "$q"=>{:definition=>"Format of the digital image", :repeat=>false}},
     :group=>"3XX"},
    "355"=>
    {:definition=>"Security Classification Control",
     :repeat=>true,
     :indicators=>[{:definition=>"Controlled element",
                    :values=>{"0"=>"Document",
                              "1"=>"Title",
                              "2"=>"Abstract",
                              "3"=>"Contents note",
                              "4"=>"Author",
                              "5"=>"Record",
                              "8"=>"None of the above"}},
                   :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Security classification", :repeat=>false},
       "$b"=>{:definition=>"Handling instructions"},
       "$c"=>{:definition=>"External dissemination information"},
       "$d"=>{:definition=>"Downgrading or declassification event", :repeat=>false},
       "$e"=>{:definition=>"Classification system", :repeat=>false},
       "$f"=>{:definition=>"Country of origin code", :repeat=>false},
       "$g"=>{:definition=>"Downgrading date", :repeat=>false},
       "$h"=>{:definition=>"Declassification date", :repeat=>false},
       "$j"=>{:definition=>"Authorization"}},
     :group=>"3XX"},
    "357"=>
    {:definition=>"Originator Dissemination Control",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Originator control term", :repeat=>false},
       "$b"=>{:definition=>"Originating agency"},
       "$c"=>{:definition=>"Authorized recipients of material"},
       "$g"=>{:definition=>"Other restrictions"}},
     :group=>"3XX"},
    "362"=>
    {:definition=>"Dates of Publication and/or Sequential Designation",
     :repeat=>true,
     :indicators=>[{:definition=>"Format of date",
                    :values=>{"0"=>"Formatted style",
                              "1"=>"Unformatted note"}},
                   :undefined],
     :subfields=>{
       "$a"=>{
         :definition=>"Dates of publication and/or sequential designation",
         :repeat=>false},
       "$z"=>{:definition=>"Source of information", :repeat=>false}},
     :group=>"3XX"},
    "363"=>
    {:definition=>"Normalized Date and Sequential Designation",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Start/End designator",
       :values=>{"#"=>"No information provided",
                 "0"=>"Starting information",
                 "1"=>"Ending information"}},
      {:definition=>"State of issuance", :values=>{"#"=>"Not specified",
                                                   "0"=>"Closed",
                                                   "1"=>"Open"}}],
     :subfields=>{
       "$a"=>{:definition=>"First level of enumeration", :repeat=>false},
       "$b"=>{:definition=>"Second level of enumeration", :repeat=>false},
       "$c"=>{:definition=>"Third level of enumeration", :repeat=>false},
       "$d"=>{:definition=>"Fourth level of enumeration", :repeat=>false},
       "$e"=>{:definition=>"Fifth level of enumeration", :repeat=>false},
       "$f"=>{:definition=>"Sixth level of enumeration", :repeat=>false},
       "$g"=>{
         :definition=>"Alternative numbering scheme, first level of enumeration",
         :repeat=>false},
       "$h"=>{
         :definition=>"Alternative numbering scheme, second level of enumeration",
         :repeat=>false},
       "$i"=>{:definition=>"First level of chronology", :repeat=>false},
       "$j"=>{:definition=>"Second level of chronology", :repeat=>false},
       "$k"=>{:definition=>"Third level of chronology", :repeat=>false},
       "$l"=>{:definition=>"Fourth level of chronology", :repeat=>false},
       "$m"=>{:definition=>"Alternative numbering scheme, chronology",
              :repeat=>false},
       "$u"=>{:definition=>"First level textual designation", :repeat=>false},
       "$v"=>{:definition=>"First level of chronology, issuance", :repeat=>false},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE},
     :group=>"3XX"},
    "365"=>
    {:definition=>"Trade Price",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Price type code", :repeat=>false},
       "$b"=>{:definition=>"Price amount", :repeat=>false},
       "$c"=>{:definition=>"Currency code", :repeat=>false},
       "$d"=>{:definition=>"Unit of pricing", :repeat=>false},
       "$e"=>{:definition=>"Price note", :repeat=>false},
       "$f"=>{:definition=>"Price effective from", :repeat=>false},
       "$g"=>{:definition=>"Price effective until", :repeat=>false},
       "$h"=>{:definition=>"Tax rate 1", :repeat=>false},
       "$i"=>{:definition=>"Tax rate 2", :repeat=>false},
       "$j"=>{:definition=>"ISO country code", :repeat=>false},
       "$k"=>{:definition=>"MARC country code", :repeat=>false},
       "$m"=>{:definition=>"Identification of pricing entity", :repeat=>false},
       "$2"=>{:definition=>"Source of price type code", :repeat=>false},},
     :group=>"3XX"},
    "366"=>
    {:definition=>"Trade Availability Information",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Publishers' compressed title identification",
              :repeat=>false},
       "$b"=>{:definition=>"Detailed date of publication", :repeat=>false},
       "$c"=>{:definition=>"Availability status code", :repeat=>false},
       "$d"=>{:definition=>"Expected next availability date", :repeat=>false},
       "$e"=>{:definition=>"Note", :repeat=>false},
       "$f"=>{:definition=>"Publisher's discount category", :repeat=>false},
       "$g"=>{:definition=>"Date made out of print", :repeat=>false},
       "$j"=>{:definition=>"ISO country code", :repeat=>false},
       "$k"=>{:definition=>"MARC country code", :repeat=>false},
       "$m"=>{:definition=>"Identification of agency", :repeat=>false},
       "$2"=>{:definition=>"Source of availability status code", :repeat=>false}},
     :group=>"3XX"},
    "370"=>
    {:definition=>"Associated Place",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$c"=>{:definition=>"Associated country"},
      "$f"=>{:definition=>"Other associated place"},
      "$g"=>
      {:definition=>"Place of origin of work or expression"},
      "$i"=>RELINFO,
      "$s"=>{:definition=>"Start period", :repeat=>false},
      "$t"=>{:definition=>"End period", :repeat=>false},
      "$u"=>{:definition=>"Uniform Resource Identifier"},
      "$v"=>{:definition=>"Source of information"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SRCTERM,
      "$3"=>MATSPEC,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"3XX"},
    "377"=>
    {:definition=>"Associated Language",
     :repeat=>true,
     :indicators=>
     [:undefined,
      {:definition=>"Source of code",
       :values=>{"#"=>"MARC language code", "7"=>"Source specified in $2"}}],
     :subfields=>
     {"$a"=>{:definition=>"Language code"},
      "$l"=>{:definition=>"Language term"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "380"=>
    {:definition=>"Form of Work",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Form of work"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SRCTERM,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "381"=>
    {:definition=>"Other Distinguishing Characteristics of Work or Expression",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Other distinguishing characteristic"},
      "$u"=>{:definition=>"Uniform Resource Identifier"},
      "$v"=>{:definition=>"Source of information"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SRCTERM,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "382"=>
    {:definition=>"Medium of Performance",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>
       {"#"=>"No information provided",
        "0"=>"Medium of performance",
        "1"=>"Partial medium of performance"}},
      {:definition=>"Access control",
       :values=>
       {"#"=>"No information provided",
        "0"=>"Not intended for access",
        "1"=>"Intended for access"}}],
     :subfields=>
     {"$a"=>{:definition=>"Medium of performance"},
      "$b"=>{:definition=>"Soloist"},
      "$d"=>{:definition=>"Doubling instrument"},
      "$e"=>
      {:definition=>"Number of ensembles of the same type"},
      "$n"=>
      {:definition=>"Number of performers of the same medium"},
      "$p"=>{:definition=>"Alternative medium of performance"},
      "$r"=>
      {:definition=>
       "Total number of individuals performing alongside ensembles",
       :repeat=>false},
      "$s"=>{:definition=>"Total number of performers", :repeat=>false},
      "$t"=>{:definition=>"Total number of ensembles", :repeat=>false},
      "$v"=>NOTER,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SRCTERM,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "383"=>
    {:definition=>"Numeric Designation of Musical Work",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Serial number"},
      "$b"=>{:definition=>"Opus number"},
      "$c"=>{:definition=>"Thematic index number"},
      "$d"=>{:definition=>"Thematic index code", :repeat=>false},
      "$e"=>
      {:definition=>"Publisher associated with opus number", :repeat=>false},
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "384"=>
    {:definition=>"Key",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Key type",
       :values=>
       {"#"=>"Relationship to original unknown",
        "0"=>"Original key",
        "1"=>"Transposed key"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Key", :repeat=>false},
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "385"=>
    {:definition=>"Audience Characteristics",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Audience term"},
      "$b"=>{:definition=>"Audience code"},
      "$m"=>{:definition=>"Demographic group term", :repeat=>false},
      "$n"=>{:definition=>"Demographic group code", :repeat=>false},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "386"=>
    {:definition=>"Creator/Contributor Characteristics",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Creator/contributor term"},
      "$b"=>{:definition=>"Creator/contributor code"},
      "$i"=>RELINFO,
      "$m"=>{:definition=>"Demographic group term", :repeat=>false},
      "$n"=>{:definition=>"Demographic group code", :repeat=>false},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$3"=>MATSPEC,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"3XX"},
    "388"=>
    {:definition=>"Time Period of Creation",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of time period",
       :values=>
       {"#"=>"No information provided",
        "1"=>"Creation of work",
        "2"=>"Creation of aggregate work"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Time period of creation term"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SRCTERM,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"3XX"},
    "490"=>
    {:definition=>"Series Statement",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Series tracing policy",
       :values=>{"0"=>"Series not traced",
                 "1"=>"Series traced"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Series statement"},
       "$l"=>{:definition=>"Library of Congress call number", :repeat=>false},
       "$v"=>{:definition=>"Volume/sequential designation"},
       "$x"=>ISSNR,
       "$3"=>MATSPEC},
     :group=>"4XX"},
    "500"=>
    {:definition=>"General Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"General note", :repeat=>false},
       "$3"=>MATSPEC,
       "$5"=>INSTAPP},
     :group=>"5XX"},
    "501"=>
    {:definition=>"With Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"With note", :repeat=>false},
       "$5"=>INSTAPP},
     :group=>"5XX"},
    "502"=>
    {:definition=>"Dissertation Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Dissertation note", :repeat=>false},
       "$b"=>{:definition=>"Degree type", :repeat=>false},
       "$c"=>{:definition=>"Name of granting institution", :repeat=>false},
       "$d"=>{:definition=>"Year degree granted", :repeat=>false},
       "$g"=>MISCINF,
       "$o"=>{:definition=>"Dissertation identifier"}},
     :group=>"5XX"},
    "504"=>
    {:definition=>"Bibliography, Etc. Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Bibliography, etc. note", :repeat=>false},
       "$b"=>{:definition=>"Number of references", :repeat=>false}},
     :group=>"5XX"},
    "505"=>
    {:definition=>"Formatted Contents Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"0"=>"Contents",
                 "1"=>"Incomplete contents",
                 "2"=>"Partial contents",
                 "8"=>"No display constant generated"}},
      {:definition=>"Level of content designation",
       :values=>{
         "#"=>"Basic",
         "0"=>"Enhanced"}}],
     :subfields=>{
       "$a"=>{:definition=>"Formatted contents note", :repeat=>false},
       "$g"=>MISCINF,
       "$r"=>{:definition=>"Statement of responsibility"},
       "$t"=>{:definition=>"Title"},
       "$u"=>{:definition=>"Uniform Resource Identifier"}},
     :group=>"5XX"},
    "506"=>
    {:definition=>"Restrictions on Access Note",
     :repeat=>true,
     :indicators=>[{:definition=>"Restriction",
                    :values=>{"#"=>"No information provided",
                              "0"=>"No restrictions",
                              "1"=>"Restrictions apply"}},
                   :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Terms governing access", :repeat=>false},
       "$b"=>{:definition=>"Jurisdiction"},
       "$c"=>{:definition=>"Physical access provisions"},
       "$d"=>{:definition=>"Authorized users"},
       "$e"=>{:definition=>"Authorization"},
       "$f"=>{:definition=>"Standardized terminology for access restriction"},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$2"=>SRCTERM,
       "$3"=>MATSPEC,
       "$5"=>INSTAPP},
     :group=>"5XX"},
    "507"=>
    {:definition=>"Scale Note for Graphic Material",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Representative fraction of scale note",
              :repeat=>false},
       "$b"=>{:definition=>"Remainder of scale note", :repeat=>false}},
     :group=>"5XX"},
    "508"=>
    {:definition=>"Creation/Production Credits Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Creation/production credits note", :repeat=>false}},
     :group=>"5XX"},
    "510"=>
    {:definition=>"Citation/References Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Coverage/location in source",
       :values=>
       {"0"=>"Coverage unknown",
        "1"=>"Coverage complete",
        "2"=>"Coverage is selective",
        "3"=>"Location in source not given",
        "4"=>"Location in source given"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Name of source", :repeat=>false},
      "$b"=>{:definition=>"Coverage of source", :repeat=>false},
      "$c"=>{:definition=>"Location within source", :repeat=>false},
      "$u"=>{:definition=>"Uniform Resource Identifier"},
      "$x"=>ISSNNR,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"5XX"},
    "511"=>
    {:definition=>"Participant or Performer Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"0"=>"No display constant generated",
                 "1"=>"Cast"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Participant or performer note", :repeat=>false}},
     :group=>"5XX"},
    "513"=>
    {:definition=>"Type of Report and Period Covered Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Type of report", :repeat=>false},
       "$b"=>{:definition=>"Period covered", :repeat=>false}},
     :group=>"5XX"},
    "514"=>
    {:definition=>"Data Quality Note",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Attribute accuracy report", :repeat=>false},
       "$b"=>{:definition=>"Attribute accuracy value"},
       "$c"=>{:definition=>"Attribute accuracy explanation"},
       "$d"=>{:definition=>"Logical consistency report", :repeat=>false},
       "$e"=>{:definition=>"Completeness report", :repeat=>false},
       "$f"=>{:definition=>"Horizontal position accuracy report", :repeat=>false},
       "$g"=>{:definition=>"Horizontal position accuracy value"},
       "$h"=>{:definition=>"Horizontal position accuracy explanation"},
       "$i"=>{:definition=>"Vertical positional accuracy report", :repeat=>false},
       "$j"=>{:definition=>"Vertical positional accuracy value"},
       "$k"=>{:definition=>"Vertical positional accuracy explanation"},
       "$m"=>{:definition=>"Cloud cover", :repeat=>false},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$z"=>{:definition=>"Display note"}},
     :group=>"5XX"},
    "515"=>
    {:definition=>"Numbering Peculiarities Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{"$a"=>{:definition=>"Numbering peculiarities note",
                         :repeat=>false}},
     :group=>"5XX"},
    "516"=>
    {:definition=>"Type of Computer File or Data Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"Type of file",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Type of computer file or data note",
              :repeat=>false}},
     :group=>"5XX"},
    "518"=>
    {:definition=>"Date/Time and Place of an Event Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>
      {:definition=>"Date/time and place of an event note", :repeat=>false},
      "$d"=>{:definition=>"Date of event"},
      "$o"=>{:definition=>"Other event information"},
      "$p"=>{:definition=>"Place of event"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>{:definition=>"Source of term"},
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"5XX"},
    "520"=>
    {:definition=>"Summary, Etc.",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"Summary",
                 "0"=>"Subject",
                 "1"=>"Review",
                 "2"=>"Scope and content",
                 "3"=>"Abstract",
                 "4"=>"Content advice",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Summary, etc.", :repeat=>false},
       "$b"=>{:definition=>"Expansion of summary note", :repeat=>false},
       "$c"=>{:definition=>"Assigning source", :repeat=>false},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$2"=>SOURCE,
       "$3"=>MATSPEC},
     :group=>"5XX"},
    "521"=>
    {:definition=>"Target Audience Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller", 
       :values=>{"#"=>"Audience",
                 "0"=>"Reading grade level",
                 "1"=>"Interest age level",
                 "2"=>"Interest grade level",
                 "3"=>"Special audience characteristics",
                 "4"=>"Motivation/interest level",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Target audience note"},
       "$b"=>SOURCE,
       "$3"=>MATSPEC},
     :group=>"5XX"},
    "522"=>
    {:definition=>"Geographic Coverage Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"Geographic coverage",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Geographic coverage note", :repeat=>false}},
     :group=>"5XX"},
    "524"=>
    {:definition=>"Preferred Citation of Described Materials Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"Cite as",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Preferred citation of described materials note",
              :repeat=>false},
       "$2"=>{:definition=>"Source of schema used", :repeat=>false},
       "$3"=>MATSPEC},
     :group=>"5XX"},
    "525"=>
    {:definition=>"Supplement Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{"$a"=>{:definition=>"Supplement note", :repeat=>false}},
     :group=>"5XX"},
    "526"=>
    {:definition=>"Study Program Information Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"0"=>"Reading program",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Program name", :repeat=>false},
       "$b"=>{:definition=>"Interest level", :repeat=>false},
       "$c"=>{:definition=>"Reading level", :repeat=>false},
       "$d"=>{:definition=>"Title point value", :repeat=>false},
       "$i"=>{:definition=>"Display text", :repeat=>false},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE,
       "$5"=>INSTAPP},
     :group=>"5XX"},
    "530"=>
    {:definition=>"Additional Physical Form Available Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Additional physical form available note",
              :repeat=>false},
       "$b"=>{:definition=>"Availability source", :repeat=>false},
       "$c"=>{:definition=>"Availability conditions", :repeat=>false},
       "$d"=>{:definition=>"Order number", :repeat=>false},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$3"=>MATSPEC},
     :group=>"5XX"},
    "533"=>
    {:definition=>"Reproduction Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Type of reproduction", :repeat=>false},
       "$b"=>{:definition=>"Place of reproduction"},
       "$c"=>{:definition=>"Agency responsible for reproduction"},
       "$d"=>{:definition=>"Date of reproduction", :repeat=>false},
       "$e"=>{:definition=>"Physical description of reproduction",
              :repeat=>false},
       "$f"=>{:definition=>"Series statement of reproduction"},
       "$m"=>{
         :definition=>"Dates and/or sequential designation of issues reproduced"},
       "$n"=>{:definition=>"Note about reproduction"},
       "$3"=>MATSPEC,
       "$5"=>INSTAPP,
       "$7"=>{:definition=>"Fixed-length data elements of reproduction",
              :repeat=>false}},
     :group=>"5XX"},
    "534"=>
    {:definition=>"Original Version Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Main entry of original", :repeat=>false},
       "$b"=>{:definition=>"Edition statement of original", :repeat=>false},
       "$c"=>{:definition=>"Publication, distribution, etc. of original",
              :repeat=>false},
       "$e"=>{:definition=>"Physical description, etc. of original",
              :repeat=>false},
       "$f"=>{:definition=>"Series statement of original"},
       "$k"=>{:definition=>"Key title of original"},
       "$l"=>{:definition=>"Location of original", :repeat=>false},
       "$m"=>{:definition=>"Material specific details", :repeat=>false},
       "$n"=>{:definition=>"Note about original"},
       "$o"=>{:definition=>"Other resource identifier"},
       "$p"=>{:definition=>"Introductory phrase", :repeat=>false},
       "$t"=>{:definition=>"Title statement of original", :repeat=>false},
       "$x"=>ISSNR,
       "$z"=>ISBNR,
       "$3"=>MATSPEC},
     :group=>"5XX"},
    "535"=>
    {:definition=>"Location of Originals/Duplicates Note",
     :repeat=>true,
     :indicators=>[{:definition=>"Custodial role",
                    :values=>{"1"=>"Holder of originals",
                              "2"=>"Holder of duplicates"}},
                   :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Custodian", :repeat=>false},
       "$b"=>{:definition=>"Postal address"},
       "$c"=>{:definition=>"Country"},
       "$d"=>{:definition=>"Telecommunications address"},
       "$g"=>{:definition=>"Repository location code", :repeat=>false},
       "$3"=>MATSPEC},
     :group=>"5XX"},
    "536"=>
    {:definition=>"Funding Information Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Text of note", :repeat=>false},
       "$b"=>{:definition=>"Contract number"},
       "$c"=>{:definition=>"Grant number"},
       "$d"=>{:definition=>"Undifferentiated number"},
       "$e"=>{:definition=>"Program element number"},
       "$f"=>{:definition=>"Project number"},
       "$g"=>{:definition=>"Task number"},
       "$h"=>{:definition=>"Work unit number"}},
     :group=>"5XX"},
    "538"=>
    {:definition=>"System Details Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"System details note", :repeat=>false},
       "$i"=>{:definition=>"Display text", :repeat=>false},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$3"=>MATSPEC,
       "$5"=>{:definition=>"Institution to which field applies"}},
     :group=>"5XX"},
    "540"=>
    {:definition=>"Terms Governing Use and Reproduction Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Terms governing use and reproduction",
              :repeat=>false},
       "$b"=>{:definition=>"Jurisdiction", :repeat=>false},
       "$c"=>{:definition=>"Authorization", :repeat=>false},
       "$d"=>{:definition=>"Authorized users", :repeat=>false},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$3"=>MATSPEC,
       "$5"=>INSTAPP},
     :group=>"5XX"},
    "541"=>
    {:definition=>"Immediate Source of Acquisition Note",
     :repeat=>true,
     :indicators=>[{:definition=>"Privacy",
                    :values=>{"#"=>"No information provided",
                              "0"=>"Private",
                              "1"=>"Not private"}},
                   :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Source of acquisition", :repeat=>false},
       "$b"=>{:definition=>"Address", :repeat=>false},
       "$c"=>{:definition=>"Method of acquisition", :repeat=>false},
       "$d"=>{:definition=>"Date of acquisition", :repeat=>false},
       "$e"=>{:definition=>"Accession number", :repeat=>false},
       "$f"=>{:definition=>"Owner", :repeat=>false},
       "$h"=>{:definition=>"Purchase price", :repeat=>false},
       "$n"=>{:definition=>"Extent"},
       "$o"=>{:definition=>"Type of unit"},
       "$3"=>MATSPEC,
       "$5"=>INSTAPP},
     :group=>"5XX"},
    "542"=>
    {:definition=>"Information Relating to Copyright Status",
     :repeat=>true,
     :indicators=>[{:definition=>"Privacy",
                    :values=>{"#"=>"No information provided",
                              "0"=>"Private",
                              "1"=>"Not private"}}, 
                   :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Personal creator", :repeat=>false},
       "$b"=>{:definition=>"Personal creator death date", :repeat=>false},
       "$c"=>{:definition=>"Corporate creator", :repeat=>false},
       "$d"=>{:definition=>"Copyright holder"},
       "$e"=>{:definition=>"Copyright holder contact information"},
       "$f"=>{:definition=>"Copyright statement"},
       "$g"=>{:definition=>"Copyright date", :repeat=>false},
       "$h"=>{:definition=>"Copyright renewal date"},
       "$i"=>{:definition=>"Publication date", :repeat=>false},
       "$j"=>{:definition=>"Creation date", :repeat=>false},
       "$k"=>{:definition=>"Publisher"},
       "$l"=>{:definition=>"Copyright status", :repeat=>false},
       "$m"=>{:definition=>"Publication status", :repeat=>false},
       "$n"=>NOTER,
       "$o"=>{:definition=>"Research date", :repeat=>false},
       "$p"=>{:definition=>"Country of publication or creation"},
       "$q"=>{:definition=>"Supplying agency", :repeat=>false},
       "$r"=>{:definition=>"Jurisdiction of copyright assessment",
              :repeat=>false},
       "$s"=>{:definition=>"Source of information", :repeat=>false},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$3"=>MATSPEC},
     :group=>"5XX"},
    "544"=>
    {:definition=>"Location of Other Archival Materials Note",
     :repeat=>true,
     :indicators=>[{:definition=>"Relationship",
                    :values=>{"#"=>"No information provided",
                              "0"=>"Associated materials",
                              "1"=>"Related materials"}},
                   :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Custodian"},
       "$b"=>{:definition=>"Address"},
       "$c"=>{:definition=>"Country"},
       "$d"=>{:definition=>"Title"},
       "$e"=>{:definition=>"Provenance"},
       "$n"=>NOTER,
       "$3"=>MATSPEC},
     :group=>"5XX"},
    "545"=>
    {:definition=>"Biographical or Historical Data",
     :repeat=>true,
     :indicators=>[{:definition=>"Type of data",
                    :values=>{"#"=>"No information provided",
                              "0"=>"Biographical sketch",
                              "1"=>"Administrative history"}},
                   :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Biographical or historical data", :repeat=>false},
       "$b"=>{:definition=>"Expansion", :repeat=>false},
       "$u"=>{:definition=>"Uniform Resource Identifier"}},
     :group=>"5XX"},
    "546"=>
    {:definition=>"Language Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Language note", :repeat=>false},
      "$b"=>{:definition=>"Information code or alphabet"},
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"5XX"},
    "547"=>
    {:definition=>"Former Title Complexity Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Former title complexity note",
              :repeat=>false}},
     :group=>"5XX"},
    "550"=>
    {:definition=>"Issuing Body Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Issuing body note",
              :repeat=>false}},
     :group=>"5XX"},
    "552"=>
    {:definition=>"Entity and Attribute Information Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Entity type label", :repeat=>false},
       "$b"=>{:definition=>"Entity type definition and source", :repeat=>false},
       "$c"=>{:definition=>"Attribute label", :repeat=>false},
       "$d"=>{:definition=>"Attribute definition and source", :repeat=>false},
       "$e"=>{:definition=>"Enumerated domain value"},
       "$f"=>{:definition=>"Enumerated domain value definition and source"},
       "$g"=>{:definition=>"Range domain minimum and maximum", :repeat=>false},
       "$h"=>{:definition=>"Codeset name and source", :repeat=>false},
       "$i"=>{:definition=>"Unrepresentable domain", :repeat=>false},
       "$j"=>{:definition=>"Attribute units of measurement and resolution",
              :repeat=>false},
       "$k"=>{:definition=>"Beginning and ending date of attribute values",
              :repeat=>false},
       "$l"=>{:definition=>"Attribute value accuracy", :repeat=>false},
       "$m"=>{:definition=>"Attribute value accuracy explanation",
              :repeat=>false},
       "$n"=>{:definition=>"Attribute measurement frequency", :repeat=>false},
       "$o"=>{:definition=>"Entity and attribute overview"},
       "$p"=>{:definition=>"Entity and attribute detail citation"},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$z"=>{:definition=>"Display note"}},
     :group=>"5XX"},
    "555"=>
    {:definition=>"Cumulative Index/Finding Aids Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"Indexes",
                 "0"=>"Finding aids",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Cumulative index/finding aids note", :repeat=>false},
       "$b"=>{:definition=>"Availability source"},
       "$c"=>{:definition=>"Degree of control", :repeat=>false},
       "$d"=>{:definition=>"Bibliographic reference", :repeat=>false},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$3"=>MATSPEC},
     :group=>"5XX"},
    "556"=>
    {:definition=>"Information About Documentation Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"Documentation",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Information about documentation note",
              :repeat=>false},
       "$z"=>ISBNR},
     :group=>"5XX"},
    "561"=>
    {:definition=>"Ownership and Custodial History",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Privacy",
       :values=>
       {"#"=>"No information provided", "0"=>"Private", "1"=>"Not private"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"History", :repeat=>false},
      "$u"=>{:definition=>"Uniform Resource Identifier"},
      "$3"=>MATSPEC,
      "$5"=>INSTAPP},
     :linkage=>true,
     :group=>"5XX"},
    "562"=>
    {:definition=>"Copy and Version Identification Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Identifying markings"},
       "$b"=>{:definition=>"Copy identification"},
       "$c"=>{:definition=>"Version identification"},
       "$d"=>{:definition=>"Presentation format"},
       "$e"=>{:definition=>"Number of copies"},
       "$3"=>MATSPEC,
       "$5"=>{:definition=>"Institution to which field applies",
              :repeat=>false}},
     :group=>"5XX"},
    "563"=>
    {:definition=>"Binding Information",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Binding note", :repeat=>false},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$3"=>MATSPEC,
       "$5"=>{:definition=>"Institution to which field applies",
              :repeat=>false}},
     :group=>"5XX"},
    "565"=>
    {:definition=>"Case File Characteristics Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"File size",
                 "0"=>"Case file characteristics",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Number of cases/variables", :repeat=>false},
       "$b"=>{:definition=>"Name of variable"},
       "$c"=>{:definition=>"Unit of analysis"},
       "$d"=>{:definition=>"Universe of data"},
       "$e"=>{:definition=>"Filing scheme or code"},
       "$3"=>MATSPEC},
     :group=>"5XX"},
    "567"=>
    {:definition=>"Methodology Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"Methodology", "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Methodology note", :repeat=>false},
      "$b"=>{:definition=>"Controlled term"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SRCTERM},
     :linkage=>true,
     :group=>"5XX"},
    "580"=>
    {:definition=>"Linking Entry Complexity Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Linking entry complexity note", :repeat=>false}},
     :group=>"5XX"},
    "581"=>
    {:definition=>"Publications About Described Materials Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"Publications",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Publications about described materials note",
              :repeat=>false},
       "$z"=>ISBNR,
       "$3"=>MATSPEC},
     :group=>"5XX"},
    "583"=>
    {:definition=>"Action Note",
     :repeat=>true,
     :indicators=>[{:definition=>"Privacy",
                    :values=>{"#"=>"No information provided",
                              "0"=>"Private",
                              "1"=>"Not private"}},
                   :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Action", :repeat=>false},
       "$b"=>{:definition=>"Action identification"},
       "$c"=>{:definition=>"Time/date of action"},
       "$d"=>{:definition=>"Action interval"},
       "$e"=>{:definition=>"Contingency for action"},
       "$f"=>{:definition=>"Authorization"},
       "$h"=>{:definition=>"Jurisdiction"},
       "$i"=>{:definition=>"Method of action"},
       "$j"=>{:definition=>"Site of action"},
       "$k"=>{:definition=>"Action agent"},
       "$l"=>{:definition=>"Status"},
       "$n"=>{:definition=>"Extent"},
       "$o"=>{:definition=>"Type of unit"},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE,
       "$2"=>SRCTERM,
       "$3"=>MATSPEC,
       "$5"=>{:definition=>"Institution to which field applies",
              :repeat=>false},},
     :group=>"5XX"},
    "584"=>
    {:definition=>"Accumulation and Frequency of Use Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Accumulation"},
       "$b"=>{:definition=>"Frequency of use"},
       "$3"=>MATSPEC,
       "$5"=>{:definition=>"Institution to which field applies",
              :repeat=>false},},
     :group=>"5XX"},
    "585"=>
    {:definition=>"Exhibitions Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Exhibitions note", :repeat=>false},
       "$3"=>MATSPEC,
       "$5"=>{:definition=>"Institution to which field applies",
              :repeat=>false},},
     :group=>"5XX"},
    "586"=>
    {:definition=>"Awards Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"Awards",
                 "8"=>"No display constant generated"}},
      :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Awards note", :repeat=>false},
       "$3"=>MATSPEC,   },
     :group=>"5XX"},
    "588"=>
    {:definition=>"Source of Description Note",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Display constant controller",
       :values=>{"#"=>"No information provided",
                 "0"=>"Source of description",
                 "1"=>"Latest issue consulted"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Source of description note", :repeat=>false},
      "$5"=>INSTAPP},
     :linkage=>true,
     :group=>"5XX"},
    "59X"=>
    {:definition=>"Local Notes",
     :repeat=>true,
     :indicators=>nil,
     :subfields=>nil,
     :group=>"5XX"},
    "600"=>
    {:definition=>"Subject Added Entry-Personal Name",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of personal name entry element",
       :values=>{"0"=>"Forename", "1"=>"Surname", "3"=>"Family name"}},
      {:definition=>"Thesaurus",
       :values=>
       {"0"=>"Library of Congress Subject Headings",
        "1"=>"LC subject headings for children's literature",
        "2"=>"Medical Subject Headings",
        "3"=>"National Agricultural Library subject authority file",
        "4"=>"Source not specified",
        "5"=>"Canadian Subject Headings",
        "6"=>"Répertoire de vedettes-matière",
        "7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$a"=>{:definition=>"Personal name", :repeat=>false},
      "$b"=>{:definition=>"Numeration", :repeat=>false},
      "$c"=>
      {:definition=>"Titles and other words associated with a name",
       :repeat=>true},
      "$d"=>{:definition=>"Dates associated with a name", :repeat=>false},
      "$e"=>RELATOR,
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$j"=>{:definition=>"Attribution qualifier"},
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>NUMPART,
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$q"=>{:definition=>"Fuller form of name", :repeat=>false},
      "$r"=>MUSKEY,
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$v"=>FRMSUBD,
      "$x"=>GNRLSUB,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$3"=>MATSPEC,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"6XX"},
    "610"=>
    {:definition=>"Subject Added Entry-Corporate Name",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of corporate name entry element",
       :values=>
       {"0"=>"Inverted name",
        "1"=>"Jurisdiction name",
        "2"=>"Name in direct order"}},
      {:definition=>"Thesaurus",
       :values=>
       {"0"=>"Library of Congress Subject Headings",
        "1"=>"LC subject headings for children's literature",
        "2"=>"Medical Subject Headings",
        "3"=>"National Agricultural Library subject authority file",
        "4"=>"Source not specified",
        "5"=>"Canadian Subject Headings",
        "6"=>"Répertoire de vedettes-matière",
        "7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$a"=>
      {:definition=>"Corporate name or jurisdiction name as entry element",
       :repeat=>false},
      "$b"=>{:definition=>"Subordinate unit"},
      "$c"=>{:definition=>"Location of meeting"},
      "$d"=>{:definition=>"Date of meeting or treaty signing"},
      "$e"=>RELATOR,
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>{:definition=>"Number of part/section/meeting"},
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$r"=>MUSKEY,
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$v"=>FRMSUBD,
      "$x"=>GNRLSUB,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$3"=>MATSPEC,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"6XX"},
    "611"=>
    {:definition=>"Subject Added Entry-Meeting Name",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of meeting name entry element",
       :values=>
       {"0"=>"Inverted name",
        "1"=>"Jurisdiction name",
        "2"=>"Name in direct order"}},
      {:definition=>"Thesaurus",
       :values=>
       {"0"=>"Library of Congress Subject Headings",
        "1"=>"LC subject headings for children's literature",
        "2"=>"Medical Subject Headings",
        "3"=>"National Agricultural Library subject authority file",
        "4"=>"Source not specified",
        "5"=>"Canadian Subject Headings",
        "6"=>"Répertoire de vedettes-matière",
        "7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$a"=>
      {:definition=>"Meeting name or jurisdiction name as entry element",
       :repeat=>false},
      "$c"=>{:definition=>"Location of meeting"},
      "$d"=>{:definition=>"Date of meeting or treaty signing"},
      "$e"=>{:definition=>"Subordinate unit"},
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$j"=>RELATOR,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$n"=>{:definition=>"Number of part/section/meeting"},
      "$p"=>NAMEPRT,
      "$q"=>
      {:definition=>
       "Name of meeting following jurisdiction name entry element",
       :repeat=>false},
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$v"=>FRMSUBD,
      "$x"=>GNRLSUB,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$3"=>MATSPEC,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"6XX"},
    "630"=>
    {:definition=>"Subject Added Entry-Uniform Title",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Nonfiling characters",
       :values=>{"0-9"=>"Number of nonfiling characters"}},
      {:definition=>"Thesaurus",
       :values=>
       {"0"=>"Library of Congress Subject Headings",
        "1"=>"LC subject headings for children's literature",
        "2"=>"Medical Subject Headings",
        "3"=>"National Agricultural Library subject authority file",
        "4"=>"Source not specified",
        "5"=>"Canadian Subject Headings",
        "6"=>"Répertoire de vedettes-matière",
        "7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$a"=>UNIFORM,
      "$d"=>{:definition=>"Date of treaty signing"},
      "$e"=>RELATOR,
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>NUMPART,
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$r"=>MUSKEY,
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$v"=>FRMSUBD,
      "$x"=>GNRLSUB,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$3"=>MATSPEC,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"6XX"},
    "647"=>
    {:definition=>"Subject Added Entry-Named Event",
     :repeat=>true,
     :indicators=>
     [:undefined,
      {:definition=>"Thesaurus",
       :values=>
       {"0"=>"Library of Congress Subject Headings",
        "1"=>"LC subject headings for children's literature",
        "2"=>"Medical Subject Headings",
        "3"=>"National Agricultural Library subject authority file",
        "4"=>"Source not specified",
        "5"=>"Canadian Subject Headings",
        "6"=>"Répertoire de vedettes-matière",
        "7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$a"=>{:definition=>"Named event", :repeat=>false},
      "$c"=>{:definition=>"Location of named event"},
      "$d"=>{:definition=>"Date of named event", :repeat=>false},
      "$g"=>MISCINF,
      "$v"=>FRMSUBD,
      "$x"=>GNRLSUB,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"6XX"},
    "648"=>
    {:definition=>"Subject Added Entry-Chronological Term",
     :repeat=>true,
     :indicators=>
     [:undefined,
      {:definition=>"Thesaurus",
       :values=>
       {"0"=>"Library of Congress Subject Headings",
        "1"=>"LC subject headings for children's literature",
        "2"=>"Medical Subject Headings",
        "3"=>"National Agricultural Library subject authority file",
        "4"=>"Source not specified",
        "5"=>"Canadian Subject Headings",
        "6"=>"Répertoire de vedettes-matière",
        "7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$a"=>{:definition=>"Chronological term", :repeat=>false},
      "$v"=>FRMSUBD,
      "$x"=>GNRLSUB,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"6XX"},
    "650"=>
    {:definition=>"Subject Added Entry-Topical Term",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Level of subject",
       :values=>
       {"#"=>"No information provided",
        "0"=>"No level specified",
        "1"=>"Primary",
        "2"=>"Secondary"}},
      {:definition=>"Thesaurus",
       :values=>
       {"0"=>"Library of Congress Subject Headings",
        "1"=>"LC subject headings for children's literature",
        "2"=>"Medical Subject Headings",
        "3"=>"National Agricultural Library subject authority file",
        "4"=>"Source not specified",
        "5"=>"Canadian Subject Headings",
        "6"=>"Répertoire de vedettes-matière",
        "7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$a"=>
      {:definition=>"Topical term or geographic name entry element",
       :repeat=>false},
      "$b"=>
      {:definition=>"Topical term following geographic name entry element",
       :repeat=>false},
      "$c"=>{:definition=>"Location of event", :repeat=>false},
      "$d"=>{:definition=>"Active dates", :repeat=>false},
      "$e"=>RELATOR,
      "$g"=>MISCINF,
      "$4"=>RELAT,
      "$v"=>FRMSUBD,
      "$x"=>GNRLSUB,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"6XX"},
    "651"=>
    {:definition=>"Subject Added Entry-Geographic Name",
     :repeat=>true,
     :indicators=>
     [:undefined,
      {:definition=>"Thesaurus",
       :values=>
       {"0"=>"Library of Congress Subject Headings",
        "1"=>"LC subject headings for children's literature",
        "2"=>"Medical Subject Headings",
        "3"=>"National Agricultural Library subject authority file",
        "4"=>"Source not specified",
        "5"=>"Canadian Subject Headings",
        "6"=>"Répertoire de vedettes-matière",
        "7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$a"=>{:definition=>"Geographic name", :repeat=>false},
      "$e"=>RELATOR,
      "$g"=>MISCINF,
      "$4"=>RELAT,
      "$v"=>FRMSUBD,
      "$x"=>GNRLSUB,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"6XX"},
    "653"=>
    {:definition=>"Index Term-Uncontrolled",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Level of index term",
       :values=>{"#"=>"No information provided",
                 "0"=>"No level specified",
                 "1"=>"Primary",
                 "2"=>"Secondary"}},
      {:definition=>"Type of term or name",
       :values=>{"#"=>"No information provided",
                 "0"=>"Topical term",
                 "1"=>"Personal name",
                 "2"=>"Corporate name",
                 "3"=>"Meeting name",
                 "4"=>"Chronological term",
                 "5"=>"Geographic name",
                 "6"=>"Genre/form term"}}],
     :subfields=>{"$a"=>{:definition=>"Uncontrolled term"}},
     :group=>"6XX"},
    "654"=>
    {:definition=>"Subject Added Entry-Faceted Topical Terms",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Level of subject",
       :values=>
       {"#"=>"No information provided",
        "0"=>"No level specified",
        "1"=>"Primary",
        "2"=>"Secondary"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Focus term"},
      "$b"=>{:definition=>"Non-focus term"},
      "$c"=>{:definition=>"Facet/hierarchy designation"},
      "$e"=>RELATOR,
      "$v"=>FRMSUBD,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$3"=>MATSPEC,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"6XX"},
    "655"=>
    {:definition=>"Index Term-Genre/Form",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of heading", :values=>{"#"=>"Basic", "0"=>"Faceted"}},
      {:definition=>"Thesaurus",
       :values=>
       {"0"=>"Library of Congress Subject Headings",
        "1"=>"LC subject headings for children's literature",
        "2"=>"Medical Subject Headings",
        "3"=>"National Agricultural Library subject authority file",
        "4"=>"Source not specified",
        "5"=>"Canadian Subject Headings",
        "6"=>"Répertoire de vedettes-matière",
        "7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$a"=>{:definition=>"Genre/form data or focus term", :repeat=>false},
      "$b"=>{:definition=>"Non-focus term"},
      "$c"=>{:definition=>"Facet/hierarchy designation"},
      "$v"=>FRMSUBD,
      "$x"=>GNRLSUB,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SRCTERM,
      "$3"=>MATSPEC,
      "$5"=>INSTAPP},
     :linkage=>true,
     :group=>"6XX"},
    "656"=>
    {:definition=>"Index Term-Occupation",
     :repeat=>true,
     :indicators=>
     [:undefined,
      {:definition=>"Source of term",
       :values=>{"7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$a"=>{:definition=>"Occupation", :repeat=>false},
      "$k"=>{:definition=>"Form", :repeat=>false},
      "$v"=>FRMSUBD,
      "$x"=>GNRLSUB,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SRCTERM,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"6XX"},
    "657"=>
    {:definition=>"Index Term-Function",
     :repeat=>true,
     :indicators=>
     [:undefined,
      {:definition=>"Source of term",
       :values=>{"7"=>"Source specified in subfield $2"}}],
     :subfields=>
     {"$a"=>{:definition=>"Function", :repeat=>false},
      "$v"=>FRMSUBD,
      "$x"=>GNRLSUB,
      "$y"=>CRONSUB,
      "$z"=>GEOSUB,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SRCTERM,
      "$3"=>MATSPEC},
     :linkage=>true,
     :group=>"6XX"},
    "658"=>
    {:definition=>"Index Term-Curriculum Objective",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Main curriculum objective", :repeat=>false},
       "$b"=>{:definition=>"Subordinate curriculum objective"},
       "$c"=>{:definition=>"Curriculum code", :repeat=>false},
       "$d"=>{:definition=>"Correlation factor", :repeat=>false},
       "$2"=>{:definition=>"Source of term or code", :repeat=>false}},
     :group=>"6XX"},
    "662"=>
    {:definition=>"Subject Added Entry-Hierarchical Place Name",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Country or larger entity"},
      "$b"=>{:definition=>"First-order political jurisdiction", :repeat=>false},
      "$c"=>{:definition=>"Intermediate political jurisdiction"},
      "$d"=>{:definition=>"City", :repeat=>false},
      "$e"=>RELATOR,
      "$f"=>{:definition=>"City subsection"},
      "$g"=>
      {:definition=>"Other nonjurisdictional geographic region and feature",
       :repeat=>true},
      "$h"=>{:definition=>"Extraterrestrial area"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"6XX"},
    "69X"=>
    {:definition=>"Local Subject Access Fields",
     :repeat=>true,
     :indicators=>nil,
     :subfields=>nil,
     :group=>"6XX"},
    "700"=>
    {:definition=>"Added Entry-Personal Name",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of personal name entry element",
       :values=>{"0"=>"Forename", "1"=>"Surname", "3"=>"Family name"}},
      {:definition=>"Type of added entry",
       :values=>{"#"=>"No information provided", "2"=>"Analytical entry"}}],
     :subfields=>
     {"$a"=>{:definition=>"Personal name", :repeat=>false},
      "$b"=>{:definition=>"Numeration", :repeat=>false},
      "$c"=>
      {:definition=>"Titles and other words associated with a name",
       :repeat=>true},
      "$d"=>{:definition=>"Dates associated with a name", :repeat=>false},
      "$e"=>RELATOR,
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$i"=>RELINFO,
      "$j"=>{:definition=>"Attribution qualifier"},
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>NUMPART,
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$q"=>{:definition=>"Fuller form of name", :repeat=>false},
      "$r"=>MUSKEY,
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$x"=>ISSNNR,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$3"=>MATSPEC,
      "$4"=>RELAT,
      "$5"=>INSTAPP},
     :linkage=>true,
     :group=>"70X-75X"},
    "710"=>
    {:definition=>"Added Entry-Corporate Name",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of corporate name entry element",
       :values=>
       {"0"=>"Inverted name",
        "1"=>"Jurisdiction name",
        "2"=>"Name in direct order"}},
      {:definition=>"Type of added entry",
       :values=>{"#"=>"No information provided", "2"=>"Analytical entry"}}],
     :subfields=>
     {"$a"=>
      {:definition=>"Corporate name or jurisdiction name as entry element",
       :repeat=>false},
      "$b"=>{:definition=>"Subordinate unit"},
      "$c"=>{:definition=>"Location of meeting"},
      "$d"=>{:definition=>"Date of meeting or treaty signing"},
      "$e"=>RELATOR,
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$i"=>RELINFO,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>{:definition=>"Number of part/section/meeting"},
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$r"=>MUSKEY,
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$x"=>ISSNNR,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$3"=>MATSPEC,
      "$4"=>RELAT,
      "$5"=>INSTAPP},
     :linkage=>true,
     :group=>"70X-75X"},
    "711"=>
    {:definition=>"Added Entry-Meeting Name",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of meeting name entry element",
       :values=>
       {"0"=>"Inverted name",
        "1"=>"Jurisdiction name",
        "2"=>"Name in direct order"}},
      {:definition=>"Type of added entry",
       :values=>{"#"=>"No information provided", "2"=>"Analytical entry"}}],
     :subfields=>
     {"$a"=>
      {:definition=>"Meeting name or jurisdiction name as entry element",
       :repeat=>false},
      "$c"=>{:definition=>"Location of meeting"},
      "$d"=>{:definition=>"Date of meeting or treaty signing"},
      "$e"=>{:definition=>"Subordinate unit"},
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$i"=>RELINFO,
      "$j"=>RELATOR,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$n"=>{:definition=>"Number of part/section/meeting"},
      "$p"=>NAMEPRT,
      "$q"=>
      {:definition=>
       "Name of meeting following jurisdiction name entry element",
       :repeat=>false},
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$x"=>ISSNNR,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$3"=>MATSPEC,
      "$4"=>RELAT,
      "$5"=>INSTAPP},
     :linkage=>true,
     :group=>"70X-75X"},
    "720"=>
    {:definition=>"Added Entry-Uncontrolled Name",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of name",
       :values=>{"#"=>"Not specified", "1"=>"Personal", "2"=>"Other"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Name", :repeat=>false},
      "$e"=>RELATOR,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"70X-75X"},
    "730"=>
    {:definition=>"Added Entry-Uniform Title",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Nonfiling characters",
       :values=>{"0-9"=>"Number of nonfiling characters"}},
      {:definition=>"Type of added entry",
       :values=>{"#"=>"No information provided", "2"=>"Analytical entry"}}],
     :subfields=>
     {"$a"=>UNIFORM,
      "$d"=>{:definition=>"Date of treaty signing"},
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$i"=>RELINFO,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>NUMPART,
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$r"=>MUSKEY,
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$x"=>ISSNNR,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$3"=>MATSPEC,
      "$4"=>RELAT,
      "$5"=>INSTAPP},
     :linkage=>true,
     :group=>"70X-75X"},
    "740"=>
    {:definition=>"Added Entry-Uncontrolled Related/Analytical Title",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Nonfiling characters",
       :values=>{"0"=>"No nonfiling characters",
                 "1-9"=>"Number of nonfiling characters"}},
      {:definition=>"Type of added entry",
       :values=>{"#"=>"No information provided",
                 "2"=>"Analytical entry"}}],
     :subfields=>{
       "$a"=>{:definition=>"Uncontrolled related/analytical title",
              :repeat=>false},
       "$h"=>MEDIUM,
       "$n"=>NUMPART,
       "$p"=>NAMEPRT,
       "$5"=>INSTAPP},
     :group=>"70X-75X"},
    "751"=>
    {:definition=>"Added Entry-Geographic Name",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Geographic name", :repeat=>false},
      "$e"=>RELATOR,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$3"=>MATSPEC,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"70X-75X"},
    "752"=>
    {:definition=>"Added Entry-Hierarchical Place Name",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Country or larger entity"},
      "$b"=>{:definition=>"First-order political jurisdiction", :repeat=>false},
      "$c"=>{:definition=>"Intermediate political jurisdiction"},
      "$d"=>{:definition=>"City", :repeat=>false},
      "$e"=>RELATOR,
      "$f"=>{:definition=>"City subsection"},
      "$g"=>
      {:definition=>"Other nonjurisdictional geographic region and feature",
       :repeat=>true},
      "$h"=>{:definition=>"Extraterrestrial area"},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>HEADSRC,
      "$4"=>RELAT},
     :linkage=>true,
     :group=>"70X-75X"},
    "753"=>
    {:definition=>"System Details Access to Computer Files",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Make and model of machine", :repeat=>false},
      "$b"=>{:definition=>"Programming language", :repeat=>false},
      "$c"=>{:definition=>"Operating system", :repeat=>false},
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SRCTERM},
     :linkage=>true,
     :group=>"70X-75X"},
    "754"=>
    {:definition=>"Added Entry-Taxonomic Identification",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Taxonomic name"},
      "$c"=>{:definition=>"Taxonomic category"},
      "$d"=>{:definition=>"Common or alternative name"},
      "$x"=>{:definition=>"Non-public note"},
      "$z"=>PUBNOTE,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>{:definition=>"Source of taxonomic identification", :repeat=>false}},
     :linkage=>true,
     :group=>"70X-75X"},
    "758"=>
    {:definition=>"Resource Identifier",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Label", :repeat=>false},
      "$i"=>RELINFO,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$3"=>MATSPEC,
      "$4"=>RELAT,
      "$5"=>INSTAPP},
     :linkage=>true,
     :group=>"70X-75X"},
    "760"=>
    {:definition=>"Main Series Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>{"#"=>"Main series", "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "762"=>
    {:definition=>"Subseries Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>{"#"=>"Has subseries", "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "765"=>
    {:definition=>"Original Language Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>{"#"=>"Translation of", "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "767"=>
    {:definition=>"Translation Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>{"#"=>"Translated as", "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "770"=>
    {:definition=>"Supplement/Special Issue Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>{"#"=>"Has supplement", "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "772"=>
    {:definition=>"Supplement Parent Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>
       {"#"=>"Supplement to",
        "0"=>"Parent",
        "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "773"=>
    {:definition=>"Host Item Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>{"#"=>"In", "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$p"=>{:definition=>"Abbreviated title", :repeat=>false},
      "$q"=>{:definition=>"Enumeration and first page", :repeat=>false},
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$3"=>MATSPEC,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "774"=>
    {:definition=>"Constituent Unit Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>
       {"#"=>"Constituent unit", "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "775"=>
    {:definition=>"Other Edition Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>
       {"#"=>"Other edition available",
        "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$e"=>{:definition=>"Language code", :repeat=>false},
      "$f"=>{:definition=>"Country code", :repeat=>false},
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "776"=>
    {:definition=>"Additional Physical Form Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>
       {"#"=>"Available in another form",
        "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "777"=>
    {:definition=>"Issued With Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>{"#"=>"Issued with", "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "780"=>
    {:definition=>"Preceding Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Type of relationship",
       :values=>
       {"0"=>"Continues",
        "1"=>"Continues in part",
        "2"=>"Supersedes",
        "3"=>"Supersedes in part",
        "4"=>"Formed by the union of ... and ...",
        "5"=>"Absorbed",
        "6"=>"Absorbed in part",
        "7"=>"Separated from"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "785"=>
    {:definition=>"Succeeding Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Type of relationship",
       :values=>
       {"0"=>"Continued by",
        "1"=>"Continued in part by",
        "2"=>"Superseded by",
        "3"=>"Superseded in part by",
        "4"=>"Absorbed by",
        "5"=>"Absorbed in part by",
        "6"=>"Split into ... and ...",
        "7"=>"Merged with ... to form ...",
        "8"=>"Changed back to"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "786"=>
    {:definition=>"Data Source Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>{"#"=>"Data source", "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$j"=>{:definition=>"Period of content", :repeat=>false},
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$p"=>{:definition=>"Abbreviated title", :repeat=>false},
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$v"=>{:definition=>"Source Contribution", :repeat=>false},
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "787"=>
    {:definition=>"Other Relationship Entry",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Note controller",
       :values=>{"0"=>"Display note", "1"=>"Do not display note"}},
      {:definition=>"Display constant controller",
       :values=>{"#"=>"Related item", "8"=>"No display constant generated"}}],
     :subfields=>
     {"$a"=>MAINENT,
      "$b"=>EDTNNR,
      "$c"=>QUALINF,
      "$d"=>PLCPUB,
      "$g"=>RELPRTS,
      "$h"=>PHYSDSC,
      "$i"=>RELINFO,
      "$k"=>RELSERD,
      "$m"=>MSDETL,
      "$n"=>NOTER,
      "$o"=>OIID,
      "$r"=>REPNUM,
      "$s"=>UNIFORM,
      "$t"=>TITLENR,
      "$u"=>TECHREP,
      "$w"=>RECCTRL,
      "$x"=>ISSNNR,
      "$y"=>CODENR,
      "$z"=>ISBNR,
      "$4"=>RELAT,
      "$7"=>CTRLSUB},
     :group=>"76X-78X"},
    "800"=>
    {:definition=>"Series Added Entry-Personal Name",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of personal name entry element",
       :values=>{"0"=>"Forename", "1"=>"Surname", "3"=>"Family name"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Personal name", :repeat=>false},
      "$b"=>{:definition=>"Numeration", :repeat=>false},
      "$c"=>
      {:definition=>"Titles and other words associated with a name",
       :repeat=>true},
      "$d"=>{:definition=>"Dates associated with a name", :repeat=>false},
      "$e"=>RELATOR,
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$j"=>{:definition=>"Attribution qualifier"},
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>NUMPART,
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$q"=>{:definition=>"Fuller form of name", :repeat=>false},
      "$r"=>MUSKEY,
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$v"=>{:definition=>"Volume/sequential designation", :repeat=>false},
      "$w"=>{:definition=>"Bibliographic record control number"},
      "$x"=>ISSNNR,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$3"=>MATSPEC,
      "$4"=>RELAT,
      "$5"=>{:definition=>"Institution to which field applies"},
      "$7"=>CTRLSUB},
     :group=>"80X-83X"},
    "810"=>
    {:definition=>"Series Added Entry-Corporate Name",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of corporate name entry element",
       :values=>
       {"0"=>"Inverted name",
        "1"=>"Jurisdiction name",
        "2"=>"Name in direct order"}},
      :undefined],
     :subfields=>
     {"$b"=>{:definition=>"Subordinate unit"},
      "$c"=>{:definition=>"Location of meeting"},
      "$d"=>{:definition=>"Date of meeting or treaty signing"},
      "$e"=>RELATOR,
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>{:definition=>"Number of part/section/meeting"},
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$r"=>MUSKEY,
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$v"=>{:definition=>"Volume/sequential designation", :repeat=>false},
      "$w"=>{:definition=>"Bibliographic record control number"},
      "$x"=>ISSNNR,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$3"=>MATSPEC,
      "$4"=>RELAT,
      "$5"=>{:definition=>"Institution to which field applies"},
      "$7"=>CTRLSUB},
     :group=>"80X-83X"},
    "811"=>
    {:definition=>"Series Added Entry-Meeting Name",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Type of meeting name entry element",
       :values=>
       {"0"=>"Inverted name",
        "1"=>"Jurisdiction name",
        "2"=>"Name in direct order"}},
      :undefined],
     :subfields=>
     {"$c"=>{:definition=>"Location of meeting"},
      "$d"=>{:definition=>"Date of meeting or treaty signing"},
      "$e"=>{:definition=>"Subordinate unit"},
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$j"=>RELATOR,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$n"=>{:definition=>"Number of part/section/meeting"},
      "$p"=>NAMEPRT,
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$u"=>AFFIL,
      "$v"=>{:definition=>"Volume/sequential designation", :repeat=>false},
      "$w"=>{:definition=>"Bibliographic record control number"},
      "$x"=>ISSNNR,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$3"=>MATSPEC,
      "$4"=>RELAT,
      "$5"=>{:definition=>"Institution to which field applies"},
      "$7"=>CTRLSUB},
     :group=>"80X-83X"},
    "830"=>
    {:definition=>"Series Added Entry-Uniform Title",
     :repeat=>true,
     :indicators=>
     [:undefined,
      {:definition=>"Nonfiling characters",
       :values=>
       {"0"=>"No nonfiling characters",
        "1-9"=>"Number of nonfiling characters"}}],
     :subfields=>
     {"$a"=>UNIFORM,
      "$d"=>{:definition=>"Date of treaty signing"},
      "$f"=>DATENR,
      "$g"=>MISCINF,
      "$h"=>MEDIUM,
      "$k"=>FORMSUB,
      "$l"=>LANGNR,
      "$m"=>MUSMED,
      "$n"=>NUMPART,
      "$o"=>ARRANGE,
      "$p"=>NAMEPRT,
      "$r"=>MUSKEY,
      "$s"=>VRSNR,
      "$t"=>WRKTITL,
      "$v"=>{:definition=>"Volume/sequential designation", :repeat=>false},
      "$w"=>{:definition=>"Bibliographic record control number"},
      "$x"=>ISSNNR,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$3"=>MATSPEC,
      "$5"=>{:definition=>"Institution to which field applies"},
      "$7"=>CTRLSUB},
     :group=>"80X-83X"},
    "841"=>
    {:definition=>"Holdings Coded Data Values",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Type of record", :repeat=>false},
       "$b"=>{:definition=>"Fixed-length data elements", :repeat=>false},
       "$e"=>{:definition=>"Encoding level", :repeat=>false}},
     :linkage=>false,
     :fieldlink=>false,
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd841.html"},
    "842"=>
    {:definition=>"Textual Physical Form Designator",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Textual physical form designator", :repeat=>false}},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd842.html"},
    "843"=>
    {:definition=>"Reproduction Note",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Type of reproduction", :repeat=>false},
       "$b"=>{:definition=>"Place of reproduction"},
       "$c"=>{:definition=>"Agency responsible for reproduction"},
       "$d"=>{:definition=>"Date of reproduction", :repeat=>false},
       "$e"=>{:definition=>"Physical description of reproduction", :repeat=>false},
       "$f"=>{:definition=>"Series statement of reproduction"},
       "$m"=>{:definition=>"Dates of publication and/or sequential designation of issues reproduced"},
       "$n"=>{:definition=>"Note about reproduction"},
       "$3"=>MATSPEC,
       "$5"=>INSTAPP,
       "$7"=>{:definition=>"Fixed-length data elements of reproduction",
              :repeat=>false}},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd843.html"},
    "844"=>
    {:definition=>"Name of Unit",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{"$a"=>{:definition=>"Name of unit", :repeat=>false}},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd844.html"},
    "845"=>
    {:definition=>"Terms Governing Use and Reproduction",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Terms governing use and reproduction", :repeat=>false},
       "$b"=>{:definition=>"Jurisdiction", :repeat=>false},
       "$c"=>{:definition=>"Authorization", :repeat=>false},
       "$d"=>{:definition=>"Authorized users", :repeat=>false},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$3"=>MATSPEC,
       "$5"=>INSTAPP},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd845.html"},
    "850"=>
    {:definition=>"Holding Institution",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{"$a"=>{:definition=>"Holding institution"}},
     :linkage=>false,
     :group=>"841-88X"},
    "852"=>
    {:definition=>"Location",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Shelving scheme",
       :values=>{"#"=>"No information provided",
                 "0"=>"Library of Congress classification",
                 "1"=>"Dewey Decimal classification",
                 "2"=>"National Library of Medicine classification",
                 "3"=>"Superintendent of Documents classification",
                 "4"=>"Shelving control number",
                 "5"=>"Title",
                 "6"=>"Shelved separately",
                 "7"=>"Source specified in subfield $2",
                 "8"=>"Other scheme"}},
      {:definition=>"Shelving order",
       :values=>{"#"=>"No information provided",
                 "0"=>"Not enumeration",
                 "1"=>"Primary enumeration",
                 "2"=>"Alternative enumeration"}}],
     :subfields=>{
       "$a"=>{:definition=>"Location", :repeat=>false},
       "$b"=>{:definition=>"Sublocation or collection"},
       "$c"=>{:definition=>"Shelving location"},
       "$d"=>{:definition=>"Former shelving location"},
       "$e"=>{:definition=>"Address"},
       "$f"=>{:definition=>"Coded location qualifier"},
       "$g"=>{:definition=>"Non-coded location qualifier"},
       "$h"=>{:definition=>"Classification part", :repeat=>false},
       "$i"=>{:definition=>"Item part"},
       "$j"=>{:definition=>"Shelving control number", :repeat=>false},
       "$k"=>{:definition=>"Call number prefix"},
       "$l"=>{:definition=>"Shelving form of title", :repeat=>false},
       "$m"=>{:definition=>"Call number suffix"},
       "$n"=>{:definition=>"Country code", :repeat=>false},
       "$p"=>{:definition=>"Piece designation", :repeat=>false},
       "$q"=>{:definition=>"Piece physical condition", :repeat=>false},
       "$s"=>{:definition=>"Copyright article-fee code"},
       "$t"=>{:definition=>"Copy number", :repeat=>false},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE,
       "$2"=>{:definition=>"Source of classification or shelving scheme",
              :repeat=>false},
       "$3"=>MATSPEC},
     :group=>"841-88X"},
    "853"=>
    {:definition=>"Captions and Pattern - Basic Bibliographic Unit",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Compressibility and expandability",
       :values=>{"0"=>"Cannot compress or expand",
                 "1"=>"Can compress but not expand",
                 "2"=>"Can compress or expand",
                 "3"=>"Unknown"}},
      {:definition=>"Caption evaluation",
       :values=>{"0"=>"Captions verified; all levels present",
                 "1"=>"Captions verified; all levels present",
                 "2"=>"Captions unverified; all levels present",
                 "3"=>"Captions unverified; all levels may not be present"}}],
     :subfields=>{
       "$a"=>{:definition=>"First level of enumeration", :repeat=>false},
       "$b"=>{:definition=>"Second level of enumeration", :repeat=>false},
       "$c"=>{:definition=>"Third level of enumeration", :repeat=>false},
       "$d"=>{:definition=>"Fourth level of enumeration", :repeat=>false},
       "$e"=>{:definition=>"Fifth level of enumeration", :repeat=>false},
       "$f"=>{:definition=>"Sixth level of enumeration", :repeat=>false},
       "$g"=>{
         :definition=>"Alternative numbering scheme, first level of enumeration",
         :repeat=>false},
       "$h"=>{
         :definition=>"Alternative numbering scheme, second level of enumeration",
         :repeat=>false},
       "$i"=>{:definition=>"First level of chronology", :repeat=>false},
       "$j"=>{:definition=>"Second level of chronology", :repeat=>false},
       "$k"=>{:definition=>"Third level of chronology", :repeat=>false},
       "$l"=>{:definition=>"Fourth level of chronology", :repeat=>false},
       "$m"=>{:definition=>"Alternative numbering scheme, chronology",
              :repeat=>false},
       "$n"=>{:definition=>"Pattern note", :repeat=>false},
       "$p"=>{:definition=>"Number of pieces per issuance", :repeat=>false},
       "$u"=>{:definition=>"Bibliographic units per next higher level"},
       "$v"=>{:definition=>"Numbering continuity"},
       "$w"=>{:definition=>"Frequency", :repeat=>false},
       "$x"=>{:definition=>"Calendar change", :repeat=>false},
       "$y"=>{:definition=>"Regularity pattern"},
       "$z"=>{:definition=>"Numbering scheme"},
       "$o"=>{:definition=>"Type of unit"},
       "$t"=>{:definition=>"Copy", :repeat=>false},
       "$2"=>{:definition=>"Source of caption abbreviation"},
       "$3"=>MATSPEC},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd853.html"},
    "854"=>
    {:definition=>"Captions and Pattern - Supplementary Material",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Compressibility and expandability",
       :values=>{"0"=>"Cannot compress or expand",
                 "1"=>"Can compress but not expand",
                 "2"=>"Can compress or expand",
                 "3"=>"Unknown"}},
      {:definition=>"Caption evaluation",
       :values=>{"0"=>"Captions verified; all levels present",
                 "1"=>"Captions verified; all levels present",
                 "2"=>"Captions unverified; all levels present",
                 "3"=>"Captions unverified; all levels may not be present"}}],
     :subfields=>{
       "$a"=>{:definition=>"First level of enumeration", :repeat=>false},
       "$b"=>{:definition=>"Second level of enumeration", :repeat=>false},
       "$c"=>{:definition=>"Third level of enumeration", :repeat=>false},
       "$d"=>{:definition=>"Fourth level of enumeration", :repeat=>false},
       "$e"=>{:definition=>"Fifth level of enumeration", :repeat=>false},
       "$f"=>{:definition=>"Sixth level of enumeration", :repeat=>false},
       "$g"=>{
         :definition=>"Alternative numbering scheme, first level of enumeration",
         :repeat=>false},
       "$h"=>{
         :definition=>"Alternative numbering scheme, second level of enumeration",
         :repeat=>false},
       "$i"=>{:definition=>"First level of chronology", :repeat=>false},
       "$j"=>{:definition=>"Second level of chronology", :repeat=>false},
       "$k"=>{:definition=>"Third level of chronology", :repeat=>false},
       "$l"=>{:definition=>"Fourth level of chronology", :repeat=>false},
       "$m"=>{:definition=>"Alternative numbering scheme, chronology",
              :repeat=>false},
       "$n"=>{:definition=>"Pattern note", :repeat=>false},
       "$p"=>{:definition=>"Number of pieces per issuance", :repeat=>false},
       "$u"=>{:definition=>"Bibliographic units per next higher level"},
       "$v"=>{:definition=>"Numbering continuity"},
       "$w"=>{:definition=>"Frequency", :repeat=>false},
       "$x"=>{:definition=>"Calendar change", :repeat=>false},
       "$y"=>{:definition=>"Regularity pattern"},
       "$z"=>{:definition=>"Numbering scheme"},
       "$o"=>{:definition=>"Type of unit"},
       "$t"=>{:definition=>"Copy", :repeat=>false},
       "$2"=>{:definition=>"Source of caption abbreviation"},
       "$3"=>MATSPEC},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd854.html"},
    "855"=>
    {:definition=>"Captions and Pattern - Indexes",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"First level of enumeration", :repeat=>false},
       "$b"=>{:definition=>"Second level of enumeration", :repeat=>false},
       "$c"=>{:definition=>"Third level of enumeration", :repeat=>false},
       "$d"=>{:definition=>"Fourth level of enumeration", :repeat=>false},
       "$e"=>{:definition=>"Fifth level of enumeration", :repeat=>false},
       "$f"=>{:definition=>"Sixth level of enumeration", :repeat=>false},
       "$g"=>{
         :definition=>"Alternative numbering scheme, first level of enumeration",
         :repeat=>false},
       "$h"=>{
         :definition=>"Alternative numbering scheme, second level of enumeration",
         :repeat=>false},
       "$i"=>{:definition=>"First level of chronology", :repeat=>false},
       "$j"=>{:definition=>"Second level of chronology", :repeat=>false},
       "$k"=>{:definition=>"Third level of chronology", :repeat=>false},
       "$l"=>{:definition=>"Fourth level of chronology", :repeat=>false},
       "$m"=>{:definition=>"Alternative numbering scheme, chronology",
              :repeat=>false},
       "$n"=>{:definition=>"Pattern note", :repeat=>false},
       "$p"=>{:definition=>"Number of pieces per issuance", :repeat=>false},
       "$u"=>{:definition=>"Bibliographic units per next higher level"},
       "$v"=>{:definition=>"Numbering continuity"},
       "$w"=>{:definition=>"Frequency", :repeat=>false},
       "$x"=>{:definition=>"Calendar change", :repeat=>false},
       "$y"=>{:definition=>"Regularity pattern"},
       "$z"=>{:definition=>"Numbering scheme"},
       "$o"=>{:definition=>"Type of unit"},
       "$t"=>{:definition=>"Copy", :repeat=>false},
       "$2"=>{:definition=>"Source of caption abbreviation"},
       "$3"=>MATSPEC},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd855.html"},
    "856"=>
    {:definition=>"Electronic Location and Access",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Access method",
       :values=>{"#"=>"No information provided",
                 "0"=>"Email",
                 "1"=>"FTP",
                 "2"=>"Remote login (Telnet)",
                 "3"=>"Dial-up",
                 "4"=>"HTTP",
                 "7"=>"Method specified in subfield $2"}},
      {:definition=>"Relationship",
       :values=>{"#"=>"No information provided",
                 "0"=>"Resource",
                 "1"=>"Version of resource",
                 "2"=>"Related resource",
                 "8"=>"No display constant generated"}}],
     :subfields=>{
       "$a"=>{:definition=>"Host name"},
       "$b"=>{:definition=>"Access number"},
       "$c"=>{:definition=>"Compression information"},
       "$d"=>{:definition=>"Path"},
       "$f"=>{:definition=>"Electronic name"},
       "$h"=>{:definition=>"Processor of request", :repeat=>false},
       "$i"=>{:definition=>"Instruction"},
       "$j"=>{:definition=>"Bits per second", :repeat=>false},
       "$k"=>{:definition=>"Password", :repeat=>false},
       "$l"=>{:definition=>"Logon", :repeat=>false},
       "$m"=>{:definition=>"Contact for access assistance"},
       "$n"=>{:definition=>"Name of location of host", :repeat=>false},
       "$o"=>{:definition=>"Operating system", :repeat=>false},
       "$p"=>{:definition=>"Port", :repeat=>false},
       "$q"=>{:definition=>"Electronic format type", :repeat=>false},
       "$r"=>{:definition=>"Settings", :repeat=>false},
       "$s"=>{:definition=>"File size"},
       "$t"=>{:definition=>"Terminal emulation"},
       "$u"=>{:definition=>"Uniform Resource Identifier"},
       "$v"=>{:definition=>"Hours access method available"},
       "$w"=>RECCTRL,
       "$x"=>NPUBNOT,
       "$y"=>{:definition=>"Link text"},
       "$z"=>PUBNOTE,
       "$2"=>{:definition=>"Access method", :repeat=>false},
       "$3"=>MATSPEC},
     :group=>"841-88X"},
    "863"=>
    {:definition=>"Enumeration and Chronology - Basic Bibliographic Unit",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Field encoding level",
       :values=>{"#"=>"No information provided",
                 "3"=>"Holdings level 3",
                 "4"=>"Holdings level 4",
                 "5"=>"Holdings level 4 with piece designation"}},
      {:definition=>"Form of holdings",
       :values=>{"#"=>"No information provided",
                 "0"=>"Compressed",
                 "1"=>"Uncompressed",
                 "2"=>"Compressed, use textual display",
                 "3"=>"Uncompressed, use textual display",
                 "4"=>"Item(s) not published"}}],
     :subfields=>{
       "$a"=>{:definition=>"First level of enumeration", :repeat=>false},
       "$b"=>{:definition=>"Second level of enumeration", :repeat=>false},
       "$c"=>{:definition=>"Third level of enumeration", :repeat=>false},
       "$d"=>{:definition=>"Fourth level of enumeration", :repeat=>false},
       "$e"=>{:definition=>"Fifth level of enumeration", :repeat=>false},
       "$f"=>{:definition=>"Sixth level of enumeration", :repeat=>false},
       "$g"=>{
         :definition=>"Alternative numbering scheme, first level of enumeration",
         :repeat=>false},
       "$h"=>{
         :definition=>"Alternative numbering scheme, second level of enumeration",
         :repeat=>false},
       "$i"=>{:definition=>"First level of chronology", :repeat=>false},
       "$j"=>{:definition=>"Second level of chronology", :repeat=>false},
       "$k"=>{:definition=>"Third level of chronology", :repeat=>false},
       "$l"=>{:definition=>"Fourth level of chronology", :repeat=>false},
       "$m"=>{:definition=>"Alternative numbering scheme, chronology",
              :repeat=>false},
       "$n"=>{:definition=>"Converted Gregorian year", :repeat=>false},
       "$o"=>{:definition=>"Title of unit"},
       "$p"=>{:definition=>"Piece designation", :repeat=>false},
       "$q"=>{:definition=>"Piece physical condition", :repeat=>false},
       "$s"=>{:definition=>"Copyright article-fee code"},
       "$t"=>{:definition=>"Copy number", :repeat=>false},
       "$w"=>{:definition=>"Break indicator", :repeat=>false},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd863.html"},
    "864"=>
    {:definition=>"Enumeration and Chronology - Supplementary Material",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Field encoding level",
       :values=>{"#"=>"No information provided",
                 "3"=>"Holdings level 3",
                 "4"=>"Holdings level 4",
                 "5"=>"Holdings level 4 with piece designation"}},
      {:definition=>"Form of holdings",
       :values=>{"#"=>"No information provided",
                 "0"=>"Compressed",
                 "1"=>"Uncompressed",
                 "2"=>"Compressed, use textual display",
                 "3"=>"Uncompressed, use textual display",
                 "4"=>"Item(s) not published"}}],
     :subfields=>{
       "$a"=>{:definition=>"First level of enumeration", :repeat=>false},
       "$b"=>{:definition=>"Second level of enumeration", :repeat=>false},
       "$c"=>{:definition=>"Third level of enumeration", :repeat=>false},
       "$d"=>{:definition=>"Fourth level of enumeration", :repeat=>false},
       "$e"=>{:definition=>"Fifth level of enumeration", :repeat=>false},
       "$f"=>{:definition=>"Sixth level of enumeration", :repeat=>false},
       "$g"=>{
         :definition=>"Alternative numbering scheme, first level of enumeration",
         :repeat=>false},
       "$h"=>{
         :definition=>"Alternative numbering scheme, second level of enumeration",
         :repeat=>false},
       "$i"=>{:definition=>"First level of chronology", :repeat=>false},
       "$j"=>{:definition=>"Second level of chronology", :repeat=>false},
       "$k"=>{:definition=>"Third level of chronology", :repeat=>false},
       "$l"=>{:definition=>"Fourth level of chronology", :repeat=>false},
       "$m"=>{:definition=>"Alternative numbering scheme, chronology",
              :repeat=>false},
       "$n"=>{:definition=>"Converted Gregorian year", :repeat=>false},
       "$o"=>{:definition=>"Title of unit"},
       "$p"=>{:definition=>"Piece designation", :repeat=>false},
       "$q"=>{:definition=>"Piece physical condition", :repeat=>false},
       "$s"=>{:definition=>"Copyright article-fee code"},
       "$t"=>{:definition=>"Copy number", :repeat=>false},
       "$w"=>{:definition=>"Break indicator", :repeat=>false},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd864.html"},
    "865"=>
    {:definition=>"Enumeration and Chronology - Indexes",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Field encoding level",
       :values=>{"#"=>"No information provided",
                 "4"=>"Holdings level 4",
                 "5"=>"Holdings level 4 with piece designation"}},
      {:definition=>"Form of holdings",
       :values=>{"#"=>"No information provided",
                 "1"=>"Uncompressed"}}],
     :subfields=>{
       "$a"=>{:definition=>"First level of enumeration", :repeat=>false},
       "$b"=>{:definition=>"Second level of enumeration", :repeat=>false},
       "$c"=>{:definition=>"Third level of enumeration", :repeat=>false},
       "$d"=>{:definition=>"Fourth level of enumeration", :repeat=>false},
       "$e"=>{:definition=>"Fifth level of enumeration", :repeat=>false},
       "$f"=>{:definition=>"Sixth level of enumeration", :repeat=>false},
       "$g"=>{
         :definition=>"Alternative numbering scheme, first level of enumeration",
         :repeat=>false},
       "$h"=>{
         :definition=>"Alternative numbering scheme, second level of enumeration",
         :repeat=>false},
       "$i"=>{:definition=>"First level of chronology", :repeat=>false},
       "$j"=>{:definition=>"Second level of chronology", :repeat=>false},
       "$k"=>{:definition=>"Third level of chronology", :repeat=>false},
       "$l"=>{:definition=>"Fourth level of chronology", :repeat=>false},
       "$m"=>{:definition=>"Alternative numbering scheme, chronology",
              :repeat=>false},
       "$v"=>{:definition=>"Issuing date"},
       "$n"=>{:definition=>"Converted Gregorian year", :repeat=>false},
       "$o"=>{:definition=>"Title of unit"},
       "$p"=>{:definition=>"Piece designation", :repeat=>false},
       "$q"=>{:definition=>"Piece physical condition", :repeat=>false},
       "$s"=>{:definition=>"Copyright article-fee code"},
       "$t"=>{:definition=>"Copy number", :repeat=>false},
       "$w"=>{:definition=>"Break indicator", :repeat=>false},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd865.html"},
    "866"=>
    {:definition=>"Textual Holdings - Basic Bibliographic Unit",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Field encoding level",
       :values=>{"#"=>"No information provided",
                 "3"=>"Holdings level 3",
                 "4"=>"Holdings level 4",
                 "5"=>"Holdings level 4 with piece designation"}},
      {:definition=>"Type of notation",
       :values=>{"0"=>"Non-standard",
                 "1"=>"ANSI/NISO Z39.71 or ISO 10324",
                 "2"=>"ANSI Z39.42",
                 "7"=>"Source specified in subfield $2"}}],
     :subfields=>{
       "$a"=>{:definition=>"Textual holdings", :repeat=>false},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE,
       "$2"=>{:definition=>"Source of notation", :repeat=>false}},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd866.html"},
    "867"=>
    {:definition=>"Textual Holdings - Supplementary Material",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Field encoding level",
       :values=>{"#"=>"No information provided",
                 "3"=>"Holdings level 3",
                 "4"=>"Holdings level 4",
                 "5"=>"Holdings level 4 with piece designation"}},
      {:definition=>"Type of notation",
       :values=>{"0"=>"Non-standard",
                 "1"=>"ANSI/NISO Z39.71 or ISO 10324",
                 "2"=>"ANSI Z39.42",
                 "7"=>"Source specified in subfield $2"}}],
     :subfields=>{
       "$a"=>{:definition=>"Textual holdings", :repeat=>false},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE,
       "$2"=>{:definition=>"Source of notation", :repeat=>false}},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd867.html"},
    "868"=>
    {:definition=>"Textual Holdings - Supplementary Material",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Field encoding level",
       :values=>{"#"=>"No information provided",
                 "3"=>"Holdings level 3",
                 "4"=>"Holdings level 4",
                 "5"=>"Holdings level 4 with piece designation"}},
      {:definition=>"Type of notation",
       :values=>{"0"=>"Non-standard",
                 "1"=>"ANSI/NISO Z39.71 or ISO 10324",
                 "2"=>"ANSI Z39.42",
                 "7"=>"Source specified in subfield $2"}}],
     :subfields=>{
       "$a"=>{:definition=>"Textual holdings", :repeat=>false},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE,
       "$2"=>{:definition=>"Source of notation", :repeat=>false}},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd868.html"},
    "876"=>
    {:definition=>"Item Information - Basic Bibliographic Unit",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Internal item number", :repeat=>false},
       "$b"=>{:definition=>"Invalid or canceled internal item number"},
       "$c"=>{:definition=>"Cost"},
       "$d"=>{:definition=>"Date acquired"},
       "$e"=>{:definition=>"Source of acquisition"},
       "$h"=>{:definition=>"Use restrictions"},
       "$j"=>{:definition=>"Item status"},
       "$l"=>{:definition=>"Temporary location"},
       "$p"=>{:definition=>"Piece designation"},
       "$r"=>{:definition=>"Invalid or canceled piece designation"},
       "$t"=>{:definition=>"Copy number", :repeat=>false},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE,
       "$3"=>MATSPEC},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd876.html"},
    "877"=>
    {:definition=>"Item Information - Supplementary Material",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Internal item number", :repeat=>false},
       "$b"=>{:definition=>"Invalid or canceled internal item number"},
       "$c"=>{:definition=>"Cost"},
       "$d"=>{:definition=>"Date acquired"},
       "$e"=>{:definition=>"Source of acquisition"},
       "$h"=>{:definition=>"Use restrictions"},
       "$j"=>{:definition=>"Item status"},
       "$l"=>{:definition=>"Temporary location"},
       "$p"=>{:definition=>"Piece designation"},
       "$r"=>{:definition=>"Invalid or canceled piece designation"},
       "$t"=>{:definition=>"Copy number", :repeat=>false},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE,
       "$3"=>MATSPEC},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd877.html"},
    "878"=>
    {:definition=>"Item Information - Indexes",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Internal item number", :repeat=>false},
       "$b"=>{:definition=>"Invalid or canceled internal item number"},
       "$c"=>{:definition=>"Cost"},
       "$d"=>{:definition=>"Date acquired"},
       "$e"=>{:definition=>"Source of acquisition"},
       "$h"=>{:definition=>"Use restrictions"},
       "$j"=>{:definition=>"Item status"},
       "$l"=>{:definition=>"Temporary location"},
       "$p"=>{:definition=>"Piece designation"},
       "$r"=>{:definition=>"Invalid or canceled piece designation"},
       "$t"=>{:definition=>"Copy number", :repeat=>false},
       "$x"=>NPUBNOT,
       "$z"=>PUBNOTE,
       "$3"=>MATSPEC},
     :group=>"841-88X",
     :docurl=>"https://www.loc.gov/marc/holdings/hd878.html"},
    "880"=>
    {:definition=>"Alternate Graphic Representation",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Appropriate indicator as available in associated field",
       :values=>{}},
      {:definition=>"Appropriate indicator as available in associated field",
       :values=>{}}],
     :subfields=>{
       "$a-z"=>{:definition=>"Same as associated field", :repeat=>"n/a"},
       "$0-5"=>{:definition=>"Same as associated field", :repeat=>"n/a"},
       "$7"=>{:definition=>"Same as associated field", :repeat=>"n/a"},
       "$9"=>{:definition=>"Same as associated field", :repeat=>"n/a"}},
     :group=>"841-88X"},
    "882"=>
    {:definition=>"Replacement Record Information",
     :repeat=>false,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Replacement title"},
       "$i"=>{:definition=>"Explanatory text"},
       "$w"=>{:definition=>"Replacement bibliographic record control number"}},
     :group=>"841-88X"},
    "883"=>
    {:definition=>"Machine-generated Metadata Provenance",
     :repeat=>true,
     :indicators=>
     [{:definition=>"Method of machine assignment",
       :values=>
       {"#"=>"No information provided/not applicable",
        "0"=>"Fully machine-generated",
        "1"=>"Partially machine-generated"}},
      :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Generation process", :repeat=>false},
      "$c"=>{:definition=>"Confidence value", :repeat=>false},
      "$d"=>{:definition=>"Generation date", :repeat=>false},
      "$q"=>{:definition=>"Generation agency", :repeat=>false},
      "$x"=>{:definition=>"Validity end date", :repeat=>false},
      "$u"=>{:definition=>"Uniform Resource Identifier", :repeat=>false},
      "$w"=>{:definition=>"Bibliographic record control number"},
      "$0"=>ARECNUM,
      "$1"=>RWURI},
     :group=>"841-88X"},
    "884"=>
    {:definition=>"Description Conversion Information",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Conversion process", :repeat=>false},
      "$g"=>{:definition=>"Conversion date", :repeat=>false},
      "$k"=>{:definition=>"Identifier of source metadata", :repeat=>false},
      "$q"=>{:definition=>"Conversion agency", :repeat=>false},
      "$u"=>{:definition=>"Uniform Resource Identifier"}},
     :linkage=>false,
     :fieldlink=>false,
     :group=>"841-88X"},
    "885"=>
    {:definition=>"Matching Information",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>
     {"$a"=>{:definition=>"Matching information", :repeat=>false},
      "$b"=>
      {:definition=>"Status of matching and its checking", :repeat=>false},
      "$c"=>{:definition=>"Confidence value", :repeat=>false},
      "$d"=>{:definition=>"Generation date", :repeat=>false},
      "$w"=>RECCTRL,
      "$x"=>NPUBNOT,
      "$z"=>PUBNOTE,
      "$0"=>ARECNUM,
      "$1"=>RWURI,
      "$2"=>SOURCE,
      "$5"=>INSTAPP},
     :linkage=>false,
     :fieldlink=>false,
     :group=>"841-88X"},
    "886"=>
    {:definition=>"Foreign MARC Information Field",
     :repeat=>true,
     :indicators=>[{:definition=>"Type of field",
                    :values=>{"0"=>"Leader",
                              "1"=>"Variable control fields (002-009)",
                              "2"=>"Variable data fields (010-999)"}},
                   :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Tag of the foreign MARC field", :repeat=>false},
       "$b"=>{:definition=>"Content of the foreign MARC field", :repeat=>false},
       "$2"=>{:definition=>"Source of data", :repeat=>false},
       "$a-z"=>{:definition=>"Foreign MARC subfield"},
       "$0-9"=>{:definition=>"Foreign MARC subfield"}},
     :linkage=>false,
     :fieldlink=>false,
     :group=>"841-88X"},
    "887"=>
    {:definition=>"Non-MARC Information Field",
     :repeat=>true,
     :indicators=>[:undefined, :undefined],
     :subfields=>{
       "$a"=>{:definition=>"Content of non-MARC field", :repeat=>false},
       "$2"=>{:definition=>"Source of data", :repeat=>false}},
     :linkage=>false,
     :fieldlink=>false,
     :group=>"841-88X"}}
end  
